<?php
// This file was auto-generated from sdk-root/src/data/rekognition/2016-06-27/docs-2.json
return [ 'version' => '2.0', 'service' => '<p>This is the Amazon Rekognition API reference.</p>', 'operations' => [ 'CompareFaces' => '<p>Compares a face in the <i>source</i> input image with each of the 100 largest faces detected in the <i>target</i> input image. </p> <note> <p> If the source image contains multiple faces, the service detects the largest face and compares it with each face detected in the target image. </p> </note> <p>You pass the input and target images either as base64-encoded image bytes or as a references to images in an Amazon S3 bucket. If you use the Amazon CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file. </p> <p>In response, the operation returns an array of face matches ordered by similarity score in descending order. For each face match, the response provides a bounding box of the face, facial landmarks, pose details (pitch, role, and yaw), quality (brightness and sharpness), and confidence value (indicating the level of confidence that the bounding box contains a face). The response also provides a similarity score, which indicates how closely the faces match. </p> <note> <p>By default, only faces with a similarity score of greater than or equal to 80% are returned in the response. You can change this value by specifying the <code>SimilarityThreshold</code> parameter.</p> </note> <p> <code>CompareFaces</code> also returns an array of faces that don\'t match the source image. For each face, it returns a bounding box, confidence value, landmarks, pose details, and quality. The response also returns information about the face in the source image, including the bounding box of the face and confidence value.</p> <p>If the image doesn\'t contain Exif metadata, <code>CompareFaces</code> returns orientation information for the source and target images. Use these values to display the images with the correct image orientation.</p> <p>If no faces are detected in the source or target images, <code>CompareFaces</code> returns an <code>InvalidParameterException</code> error. </p> <note> <p> This is a stateless API operation. That is, data returned by this operation doesn\'t persist.</p> </note> <p>For an example, see <a>faces-compare-images</a>.</p> <p>This operation requires permissions to perform the <code>rekognition:CompareFaces</code> action.</p>', 'CreateCollection' => '<p>Creates a collection in an AWS Region. You can add faces to the collection using the operation. </p> <p>For example, you might create collections, one for each of your application users. A user can then index faces using the <code>IndexFaces</code> operation and persist results in a specific collection. Then, a user can search the collection for faces in the user-specific container. </p> <note> <p>Collection names are case-sensitive.</p> </note> <p>This operation requires permissions to perform the <code>rekognition:CreateCollection</code> action.</p>', 'CreateStreamProcessor' => '<p>Creates an Amazon Rekognition stream processor that you can use to detect and recognize faces in a streaming video.</p> <p>Rekognition Video is a consumer of live video from Amazon Kinesis Video Streams. Rekognition Video sends analysis results to Amazon Kinesis Data Streams.</p> <p>You provide as input a Kinesis video stream (<code>Input</code>) and a Kinesis data stream (<code>Output</code>) stream. You also specify the face recognition criteria in <code>Settings</code>. For example, the collection containing faces that you want to recognize. Use <code>Name</code> to assign an identifier for the stream processor. You use <code>Name</code> to manage the stream processor. For example, you can start processing the source video by calling with the <code>Name</code> field. </p> <p>After you have finished analyzing a streaming video, use to stop processing. You can delete the stream processor by calling .</p>', 'DeleteCollection' => '<p>Deletes the specified collection. Note that this operation removes all faces in the collection. For an example, see <a>delete-collection-procedure</a>.</p> <p>This operation requires permissions to perform the <code>rekognition:DeleteCollection</code> action.</p>', 'DeleteFaces' => '<p>Deletes faces from a collection. You specify a collection ID and an array of face IDs to remove from the collection.</p> <p>This operation requires permissions to perform the <code>rekognition:DeleteFaces</code> action.</p>', 'DeleteStreamProcessor' => '<p>Deletes the stream processor identified by <code>Name</code>. You assign the value for <code>Name</code> when you create the stream processor with . You might not be able to use the same name for a stream processor for a few seconds after calling <code>DeleteStreamProcessor</code>.</p>', 'DescribeStreamProcessor' => '<p>Provides information about a stream processor created by . You can get information about the input and output streams, the input parameters for the face recognition being performed, and the current status of the stream processor.</p>', 'DetectFaces' => '<p>Detects faces within an image that is provided as input.</p> <p> <code>DetectFaces</code> detects the 100 largest faces in the image. For each face detected, the operation returns face details including a bounding box of the face, a confidence value (that the bounding box contains a face), and a fixed set of attributes such as facial landmarks (for example, coordinates of eye and mouth), gender, presence of beard, sunglasses, etc. </p> <p>The face-detection algorithm is most effective on frontal faces. For non-frontal or obscured faces, the algorithm may not detect the faces or might detect faces with lower confidence. </p> <p>You pass the input image either as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the Amazon CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file. </p> <note> <p>This is a stateless API operation. That is, the operation does not persist any data.</p> </note> <p>For an example, see <a>procedure-detecting-faces-in-images</a>.</p> <p>This operation requires permissions to perform the <code>rekognition:DetectFaces</code> action. </p>', 'DetectLabels' => '<p>Detects instances of real-world entities within an image (JPEG or PNG) provided as input. This includes objects like flower, tree, and table; events like wedding, graduation, and birthday party; and concepts like landscape, evening, and nature. For an example, see <a>images-s3</a>.</p> <note> <p> <code>DetectLabels</code> does not support the detection of activities. However, activity detection is supported for label detection in videos. For more information, see .</p> </note> <p>You pass the input image as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the Amazon CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file. </p> <p> For each object, scene, and concept the API returns one or more labels. Each label provides the object name, and the level of confidence that the image contains the object. For example, suppose the input image has a lighthouse, the sea, and a rock. The response will include all three labels, one for each object. </p> <p> <code>{Name: lighthouse, Confidence: 98.4629}</code> </p> <p> <code>{Name: rock,Confidence: 79.2097}</code> </p> <p> <code> {Name: sea,Confidence: 75.061}</code> </p> <p> In the preceding example, the operation returns one label for each of the three objects. The operation can also return multiple labels for the same object in the image. For example, if the input image shows a flower (for example, a tulip), the operation might return the following three labels. </p> <p> <code>{Name: flower,Confidence: 99.0562}</code> </p> <p> <code>{Name: plant,Confidence: 99.0562}</code> </p> <p> <code>{Name: tulip,Confidence: 99.0562}</code> </p> <p>In this example, the detection algorithm more precisely identifies the flower as a tulip.</p> <p>In response, the API returns an array of labels. In addition, the response also includes the orientation correction. Optionally, you can specify <code>MinConfidence</code> to control the confidence threshold for the labels returned. The default is 50%. You can also add the <code>MaxLabels</code> parameter to limit the number of labels returned. </p> <note> <p>If the object detected is a person, the operation doesn\'t provide the same facial details that the <a>DetectFaces</a> operation provides.</p> </note> <p>This is a stateless API operation. That is, the operation does not persist any data.</p> <p>This operation requires permissions to perform the <code>rekognition:DetectLabels</code> action. </p>', 'DetectModerationLabels' => '<p>Detects explicit or suggestive adult content in a specified JPEG or PNG format image. Use <code>DetectModerationLabels</code> to moderate images depending on your requirements. For example, you might want to filter images that contain nudity, but not images containing suggestive content.</p> <p>To filter images, use the labels returned by <code>DetectModerationLabels</code> to determine which types of content are appropriate. For information about moderation labels, see <a>moderation</a>.</p> <p>You pass the input image either as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the Amazon CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file. </p>', 'DetectText' => '<p>Detects text in the input image and converts it into machine-readable text.</p> <p>Pass the input image as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, you must pass it as a reference to an image in an Amazon S3 bucket. For the AWS CLI, passing image bytes is not supported. The image must be either a .png or .jpeg formatted file. </p> <p>The <code>DetectText</code> operation returns text in an array of elements, <code>TextDetections</code>. Each <code>TextDetection</code> element provides information about a single word or line of text that was detected in the image. </p> <p>A word is one or more ISO basic latin script characters that are not separated by spaces. <code>DetectText</code> can detect up to 50 words in an image.</p> <p>A line is a string of equally spaced words. A line isn\'t necessarily a complete sentence. For example, a driver\'s license number is detected as a line. A line ends when there is no aligned text after it. Also, a line ends when there is a large gap between words, relative to the length of the words. This means, depending on the gap between words, Amazon Rekognition may detect multiple lines in text aligned in the same direction. Periods don\'t represent the end of a line. If a sentence spans multiple lines, the <code>DetectText</code> operation returns multiple lines.</p> <p>To determine whether a <code>TextDetection</code> element is a line of text or a word, use the <code>TextDetection</code> object <code>Type</code> field. </p> <p>To be detected, text must be within +/- 30 degrees orientation of the horizontal axis.</p> <p>For more information, see <a>text-detection</a>.</p>', 'GetCelebrityInfo' => '<p>Gets the name and additional information about a celebrity based on his or her Rekognition ID. The additional information is returned as an array of URLs. If there is no additional information about the celebrity, this list is empty. For more information, see <a>get-celebrity-info-procedure</a>.</p> <p>This operation requires permissions to perform the <code>rekognition:GetCelebrityInfo</code> action. </p>', 'GetCelebrityRecognition' => '<p>Gets the celebrity recognition results for a Rekognition Video analysis started by .</p> <p>Celebrity recognition in a video is an asynchronous operation. Analysis is started by a call to which returns a job identifier (<code>JobId</code>). When the celebrity recognition operation finishes, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to <code>StartCelebrityRecognition</code>. To get the results of the celebrity recognition analysis, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call <code>GetCelebrityDetection</code> and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartCelebrityDetection</code>. For more information, see <a>video</a>.</p> <p> <code>GetCelebrityRecognition</code> returns detected celebrities and the time(s) they are detected in an array (<code>Celebrities</code>) of objects. Each <code>CelebrityRecognition</code> contains information about the celebrity in a object and the time, <code>Timestamp</code>, the celebrity was detected. </p> <p>By default, the <code>Celebrities</code> array is sorted by time (milliseconds from the start of the video). You can also sort the array by celebrity by specifying the value <code>ID</code> in the <code>SortBy</code> input parameter.</p> <p>The <code>CelebrityDetail</code> object includes the celebrity identifer and additional information urls. If you don\'t store the additional information urls, you can get them later by calling with the celebrity identifer.</p> <p>No information is returned for faces not recognized as celebrities.</p> <p>Use MaxResults parameter to limit the number of labels returned. If there are more results than specified in <code>MaxResults</code>, the value of <code>NextToken</code> in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call <code>GetCelebrityDetection</code> and populate the <code>NextToken</code> request parameter with the token value returned from the previous call to <code>GetCelebrityRecognition</code>.</p>', 'GetContentModeration' => '<p>Gets the content moderation analysis results for a Rekognition Video analysis started by .</p> <p>Content moderation analysis of a video is an asynchronous operation. You start analysis by calling . which returns a job identifier (<code>JobId</code>). When analysis finishes, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to <code>StartContentModeration</code>. To get the results of the content moderation analysis, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call <code>GetCelebrityDetection</code> and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartCelebrityDetection</code>. For more information, see <a>video</a>. </p> <p> <code>GetContentModeration</code> returns detected content moderation labels, and the time they are detected, in an array, <code>ModerationLabels</code>, of objects. </p> <p>By default, the moderated labels are returned sorted by time, in milliseconds from the start of the video. You can also sort them by moderated label by specifying <code>NAME</code> for the <code>SortBy</code> input parameter. </p> <p>Since video analysis can return a large number of results, use the <code>MaxResults</code> parameter to limit the number of labels returned in a single call to <code>GetContentModeration</code>. If there are more results than specified in <code>MaxResults</code>, the value of <code>NextToken</code> in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call <code>GetContentModeration</code> and populate the <code>NextToken</code> request parameter with the value of <code>NextToken</code> returned from the previous call to <code>GetContentModeration</code>.</p> <p>For more information, see <a>moderation</a>.</p>', 'GetFaceDetection' => '<p>Gets face detection results for a Rekognition Video analysis started by .</p> <p>Face detection with Rekognition Video is an asynchronous operation. You start face detection by calling which returns a job identifier (<code>JobId</code>). When the face detection operation finishes, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to <code>StartFaceDetection</code>. To get the results of the face detection operation, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartFaceDetection</code>.</p> <p> <code>GetFaceDetection</code> returns an array of detected faces (<code>Faces</code>) sorted by the time the faces were detected. </p> <p>Use MaxResults parameter to limit the number of labels returned. If there are more results than specified in <code>MaxResults</code>, the value of <code>NextToken</code> in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call <code>GetFaceDetection</code> and populate the <code>NextToken</code> request parameter with the token value returned from the previous call to <code>GetFaceDetection</code>.</p>', 'GetFaceSearch' => '<p>Gets the face search results for Rekognition Video face search started by . The search returns faces in a collection that match the faces of persons detected in a video. It also includes the time(s) that faces are matched in the video.</p> <p>Face search in a video is an asynchronous operation. You start face search by calling to which returns a job identifier (<code>JobId</code>). When the search operation finishes, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to <code>StartFaceSearch</code>. To get the search results, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call <code>GetFaceSearch</code> and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartFaceSearch</code>. For more information, see <a>collections</a>.</p> <p>The search results are retured in an array, <code>Persons</code>, of objects. Each<code>PersonMatch</code> element contains details about the matching faces in the input collection, person information for the matched person, and the time the person was matched in the video.</p> <p>By default, the <code>Persons</code> array is sorted by the time, in milliseconds from the start of the video, persons are matched. You can also sort by persons by specifying <code>INDEX</code> for the <code>SORTBY</code> input parameter.</p>', 'GetLabelDetection' => '<p>Gets the label detection results of a Rekognition Video analysis started by . </p> <p>The label detection operation is started by a call to which returns a job identifier (<code>JobId</code>). When the label detection operation finishes, Amazon Rekognition publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to <code>StartlabelDetection</code>. To get the results of the label detection operation, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartLabelDetection</code>.</p> <p> <code>GetLabelDetection</code> returns an array of detected labels (<code>Labels</code>) sorted by the time the labels were detected. You can also sort by the label name by specifying <code>NAME</code> for the <code>SortBy</code> input parameter.</p> <p>The labels returned include the label name, the percentage confidence in the accuracy of the detected label, and the time the label was detected in the video.</p> <p>Use MaxResults parameter to limit the number of labels returned. If there are more results than specified in <code>MaxResults</code>, the value of <code>NextToken</code> in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call <code>GetlabelDetection</code> and populate the <code>NextToken</code> request parameter with the token value returned from the previous call to <code>GetLabelDetection</code>.</p>', 'GetPersonTracking' => '<p>Gets the person tracking results of a Rekognition Video analysis started by .</p> <p>The person detection operation is started by a call to <code>StartPersonTracking</code> which returns a job identifier (<code>JobId</code>). When the person detection operation finishes, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to <code>StartPersonTracking</code>.</p> <p>To get the results of the person tracking operation, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartPersonTracking</code>.</p> <p> <code>GetPersonTracking</code> returns an array, <code>Persons</code>, of tracked persons and the time(s) they were tracked in the video. </p> <p>By default, the array is sorted by the time(s) a person is tracked in the video. You can sort by tracked persons by specifying <code>INDEX</code> for the <code>SortBy</code> input parameter.</p> <p>Use the <code>MaxResults</code> parameter to limit the number of items returned. If there are more results than specified in <code>MaxResults</code>, the value of <code>NextToken</code> in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call <code>GetPersonTracking</code> and populate the <code>NextToken</code> request parameter with the token value returned from the previous call to <code>GetPersonTracking</code>.</p>', 'IndexFaces' => '<p>Detects faces in the input image and adds them to the specified collection. </p> <p>Amazon Rekognition does not save the actual faces detected. Instead, the underlying detection algorithm first detects the faces in the input image, and for each face extracts facial features into a feature vector, and stores it in the back-end database. Amazon Rekognition uses feature vectors when performing face match and search operations using the and operations.</p> <p>If you are using version 1.0 of the face detection model, <code>IndexFaces</code> indexes the 15 largest faces in the input image. Later versions of the face detection model index the 100 largest faces in the input image. To determine which version of the model you are using, check the the value of <code>FaceModelVersion</code> in the response from <code>IndexFaces</code>. For more information, see <a>face-detection-model</a>.</p> <p>If you provide the optional <code>ExternalImageID</code> for the input image you provided, Amazon Rekognition associates this ID with all faces that it detects. When you call the operation, the response returns the external ID. You can use this external image ID to create a client-side index to associate the faces with each image. You can then use the index to find all faces in an image. </p> <p>In response, the operation returns an array of metadata for all detected faces. This includes, the bounding box of the detected face, confidence value (indicating the bounding box contains a face), a face ID assigned by the service for each face that is detected and stored, and an image ID assigned by the service for the input image. If you request all facial attributes (using the <code>detectionAttributes</code> parameter, Amazon Rekognition returns detailed facial attributes such as facial landmarks (for example, location of eye and mount) and other facial attributes such gender. If you provide the same image, specify the same collection, and use the same external ID in the <code>IndexFaces</code> operation, Amazon Rekognition doesn\'t save duplicate face metadata. </p> <p>The input image is passed either as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the Amazon CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file. </p> <p>This operation requires permissions to perform the <code>rekognition:IndexFaces</code> action.</p>', 'ListCollections' => '<p>Returns list of collection IDs in your account. If the result is truncated, the response also provides a <code>NextToken</code> that you can use in the subsequent request to fetch the next set of collection IDs.</p> <p>For an example, see <a>list-collection-procedure</a>.</p> <p>This operation requires permissions to perform the <code>rekognition:ListCollections</code> action.</p>', 'ListFaces' => '<p>Returns metadata for faces in the specified collection. This metadata includes information such as the bounding box coordinates, the confidence (that the bounding box contains a face), and face ID. For an example, see <a>list-faces-in-collection-procedure</a>. </p> <p>This operation requires permissions to perform the <code>rekognition:ListFaces</code> action.</p>', 'ListStreamProcessors' => '<p>Gets a list of stream processors that you have created with . </p>', 'RecognizeCelebrities' => '<p>Returns an array of celebrities recognized in the input image. For more information, see <a>celebrities</a>. </p> <p> <code>RecognizeCelebrities</code> returns the 100 largest faces in the image. It lists recognized celebrities in the <code>CelebrityFaces</code> array and unrecognized faces in the <code>UnrecognizedFaces</code> array. <code>RecognizeCelebrities</code> doesn\'t return celebrities whose faces are not amongst the largest 100 faces in the image.</p> <p>For each celebrity recognized, the <code>RecognizeCelebrities</code> returns a <code>Celebrity</code> object. The <code>Celebrity</code> object contains the celebrity name, ID, URL links to additional information, match confidence, and a <code>ComparedFace</code> object that you can use to locate the celebrity\'s face on the image.</p> <p>Rekognition does not retain information about which images a celebrity has been recognized in. Your application must store this information and use the <code>Celebrity</code> ID property as a unique identifier for the celebrity. If you don\'t store the celebrity name or additional information URLs returned by <code>RecognizeCelebrities</code>, you will need the ID to identify the celebrity in a call to the operation.</p> <p>You pass the imput image either as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the Amazon CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file. </p> <p>For an example, see <a>celebrities-procedure-image</a>.</p> <p>This operation requires permissions to perform the <code>rekognition:RecognizeCelebrities</code> operation.</p>', 'SearchFaces' => '<p>For a given input face ID, searches for matching faces in the collection the face belongs to. You get a face ID when you add a face to the collection using the <a>IndexFaces</a> operation. The operation compares the features of the input face with faces in the specified collection. </p> <note> <p>You can also search faces without indexing faces by using the <code>SearchFacesByImage</code> operation.</p> </note> <p> The operation response returns an array of faces that match, ordered by similarity score with the highest similarity first. More specifically, it is an array of metadata for each face match that is found. Along with the metadata, the response also includes a <code>confidence</code> value for each face match, indicating the confidence that the specific face matches the input face. </p> <p>For an example, see <a>search-face-with-id-procedure</a>.</p> <p>This operation requires permissions to perform the <code>rekognition:SearchFaces</code> action.</p>', 'SearchFacesByImage' => '<p>For a given input image, first detects the largest face in the image, and then searches the specified collection for matching faces. The operation compares the features of the input face with faces in the specified collection. </p> <note> <p> To search for all faces in an input image, you might first call the operation, and then use the face IDs returned in subsequent calls to the operation. </p> <p> You can also call the <code>DetectFaces</code> operation and use the bounding boxes in the response to make face crops, which then you can pass in to the <code>SearchFacesByImage</code> operation. </p> </note> <p>You pass the input image either as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the Amazon CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file. </p> <p> The response returns an array of faces that match, ordered by similarity score with the highest similarity first. More specifically, it is an array of metadata for each face match found. Along with the metadata, the response also includes a <code>similarity</code> indicating how similar the face is to the input face. In the response, the operation also returns the bounding box (and a confidence level that the bounding box contains a face) of the face that Amazon Rekognition used for the input image. </p> <p>For an example, see <a>search-face-with-image-procedure</a>.</p> <p>This operation requires permissions to perform the <code>rekognition:SearchFacesByImage</code> action.</p>', 'StartCelebrityRecognition' => '<p>Starts asynchronous recognition of celebrities in a stored video.</p> <p>Rekognition Video can detect celebrities in a video must be stored in an Amazon S3 bucket. Use <a>Video</a> to specify the bucket name and the filename of the video. <code>StartCelebrityRecognition</code> returns a job identifier (<code>JobId</code>) which you use to get the results of the analysis. When celebrity recognition analysis is finished, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in <code>NotificationChannel</code>. To get the results of the celebrity recognition analysis, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartCelebrityRecognition</code>. For more information, see <a>celebrities</a>.</p>', 'StartContentModeration' => '<p> Starts asynchronous detection of explicit or suggestive adult content in a stored video.</p> <p>Rekognition Video can moderate content in a video stored in an Amazon S3 bucket. Use <a>Video</a> to specify the bucket name and the filename of the video. <code>StartContentModeration</code> returns a job identifier (<code>JobId</code>) which you use to get the results of the analysis. When content moderation analysis is finished, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in <code>NotificationChannel</code>.</p> <p>To get the results of the content moderation analysis, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartContentModeration</code>. For more information, see <a>moderation</a>.</p>', 'StartFaceDetection' => '<p>Starts asynchronous detection of faces in a stored video.</p> <p>Rekognition Video can detect faces in a video stored in an Amazon S3 bucket. Use <a>Video</a> to specify the bucket name and the filename of the video. <code>StartFaceDetection</code> returns a job identifier (<code>JobId</code>) that you use to get the results of the operation. When face detection is finished, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in <code>NotificationChannel</code>. To get the results of the label detection operation, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartFaceDetection</code>. For more information, see <a>faces-video</a>.</p>', 'StartFaceSearch' => '<p>Starts the asynchronous search for faces in a collection that match the faces of persons detected in a stored video.</p> <p>The video must be stored in an Amazon S3 bucket. Use <a>Video</a> to specify the bucket name and the filename of the video. <code>StartFaceSearch</code> returns a job identifier (<code>JobId</code>) which you use to get the search results once the search has completed. When searching is finished, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in <code>NotificationChannel</code>. To get the search results, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartFaceSearch</code>. For more information, see <a>collections-search-person</a>.</p>', 'StartLabelDetection' => '<p>Starts asynchronous detection of labels in a stored video.</p> <p>Rekognition Video can detect labels in a video. Labels are instances of real-world entities. This includes objects like flower, tree, and table; events like wedding, graduation, and birthday party; concepts like landscape, evening, and nature; and activities like a person getting out of a car or a person skiing.</p> <p>The video must be stored in an Amazon S3 bucket. Use <a>Video</a> to specify the bucket name and the filename of the video. <code>StartLabelDetection</code> returns a job identifier (<code>JobId</code>) which you use to get the results of the operation. When label detection is finished, Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in <code>NotificationChannel</code>.</p> <p>To get the results of the label detection operation, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartLabelDetection</code>.</p> <p/>', 'StartPersonTracking' => '<p>Starts the asynchronous tracking of persons in a stored video.</p> <p>Rekognition Video can track persons in a video stored in an Amazon S3 bucket. Use <a>Video</a> to specify the bucket name and the filename of the video. <code>StartPersonTracking</code> returns a job identifier (<code>JobId</code>) which you use to get the results of the operation. When label detection is finished, Amazon Rekognition publishes a completion status to the Amazon Simple Notification Service topic that you specify in <code>NotificationChannel</code>. </p> <p>To get the results of the person detection operation, first check that the status value published to the Amazon SNS topic is <code>SUCCEEDED</code>. If so, call and pass the job identifier (<code>JobId</code>) from the initial call to <code>StartPersonTracking</code>.</p>', 'StartStreamProcessor' => '<p>Starts processing a stream processor. You create a stream processor by calling . To tell <code>StartStreamProcessor</code> which stream processor to start, use the value of the <code>Name</code> field specified in the call to <code>CreateStreamProcessor</code>.</p>', 'StopStreamProcessor' => '<p>Stops a running stream processor that was created by .</p>', ], 'shapes' => [ 'AccessDeniedException' => [ 'base' => '<p>You are not authorized to perform the action.</p>', 'refs' => [], ], 'AgeRange' => [ 'base' => '<p>Structure containing the estimated age range, in years, for a face.</p> <p>Rekognition estimates an age-range for faces detected in the input image. Estimated age ranges can overlap; a face of a 5 year old may have an estimated range of 4-6 whilst the face of a 6 year old may have an estimated range of 4-8.</p>', 'refs' => [ 'FaceDetail$AgeRange' => '<p>The estimated age range, in years, for the face. Low represents the lowest estimated age and High represents the highest estimated age.</p>', ], ], 'Attribute' => [ 'base' => NULL, 'refs' => [ 'Attributes$member' => NULL, ], ], 'Attributes' => [ 'base' => NULL, 'refs' => [ 'DetectFacesRequest$Attributes' => '<p>An array of facial attributes you want to be returned. This can be the default list of attributes or all attributes. If you don\'t specify a value for <code>Attributes</code> or if you specify <code>["DEFAULT"]</code>, the API returns the following subset of facial attributes: <code>BoundingBox</code>, <code>Confidence</code>, <code>Pose</code>, <code>Quality</code> and <code>Landmarks</code>. If you provide <code>["ALL"]</code>, all facial attributes are returned but the operation will take longer to complete.</p> <p>If you provide both, <code>["ALL", "DEFAULT"]</code>, the service uses a logical AND operator to determine which attributes to return (in this case, all attributes). </p>', 'IndexFacesRequest$DetectionAttributes' => '<p>An array of facial attributes that you want to be returned. This can be the default list of attributes or all attributes. If you don\'t specify a value for <code>Attributes</code> or if you specify <code>["DEFAULT"]</code>, the API returns the following subset of facial attributes: <code>BoundingBox</code>, <code>Confidence</code>, <code>Pose</code>, <code>Quality</code> and <code>Landmarks</code>. If you provide <code>["ALL"]</code>, all facial attributes are returned but the operation will take longer to complete.</p> <p>If you provide both, <code>["ALL", "DEFAULT"]</code>, the service uses a logical AND operator to determine which attributes to return (in this case, all attributes). </p>', ], ], 'Beard' => [ 'base' => '<p>Indicates whether or not the face has a beard, and the confidence level in the determination.</p>', 'refs' => [ 'FaceDetail$Beard' => '<p>Indicates whether or not the face has a beard, and the confidence level in the determination.</p>', ], ], 'Boolean' => [ 'base' => NULL, 'refs' => [ 'Beard$Value' => '<p>Boolean value that indicates whether the face has beard or not.</p>', 'EyeOpen$Value' => '<p>Boolean value that indicates whether the eyes on the face are open.</p>', 'Eyeglasses$Value' => '<p>Boolean value that indicates whether the face is wearing eye glasses or not.</p>', 'MouthOpen$Value' => '<p>Boolean value that indicates whether the mouth on the face is open or not.</p>', 'Mustache$Value' => '<p>Boolean value that indicates whether the face has mustache or not.</p>', 'Smile$Value' => '<p>Boolean value that indicates whether the face is smiling or not.</p>', 'Sunglasses$Value' => '<p>Boolean value that indicates whether the face is wearing sunglasses or not.</p>', ], ], 'BoundingBox' => [ 'base' => '<p>Identifies the bounding box around the object, face or text. The <code>left</code> (x-coordinate) and <code>top</code> (y-coordinate) are coordinates representing the top and left sides of the bounding box. Note that the upper-left corner of the image is the origin (0,0). </p> <p>The <code>top</code> and <code>left</code> values returned are ratios of the overall image size. For example, if the input image is 700x200 pixels, and the top-left coordinate of the bounding box is 350x50 pixels, the API returns a <code>left</code> value of 0.5 (350/700) and a <code>top</code> value of 0.25 (50/200).</p> <p>The <code>width</code> and <code>height</code> values represent the dimensions of the bounding box as a ratio of the overall image dimension. For example, if the input image is 700x200 pixels, and the bounding box width is 70 pixels, the width returned is 0.1. </p> <note> <p> The bounding box coordinates can have negative values. For example, if Amazon Rekognition is able to detect a face that is at the image edge and is only partially visible, the service can return coordinates that are outside the image bounds and, depending on the image edge, you might get negative values or values greater than 1 for the <code>left</code> or <code>top</code> values. </p> </note>', 'refs' => [ 'CelebrityDetail$BoundingBox' => '<p>Bounding box around the body of a celebrity.</p>', 'ComparedFace$BoundingBox' => '<p>Bounding box of the face.</p>', 'ComparedSourceImageFace$BoundingBox' => '<p>Bounding box of the face.</p>', 'Face$BoundingBox' => '<p>Bounding box of the face.</p>', 'FaceDetail$BoundingBox' => '<p>Bounding box of the face.</p>', 'Geometry$BoundingBox' => '<p>An axis-aligned coarse representation of the detected text\'s location on the image.</p>', 'PersonDetail$BoundingBox' => '<p>Bounding box around the detected person.</p>', 'SearchFacesByImageResponse$SearchedFaceBoundingBox' => '<p>The bounding box around the face in the input image that Amazon Rekognition used for the search.</p>', ], ], 'Celebrity' => [ 'base' => '<p>Provides information about a celebrity recognized by the operation.</p>', 'refs' => [ 'CelebrityList$member' => NULL, ], ], 'CelebrityDetail' => [ 'base' => '<p>Information about a recognized celebrity.</p>', 'refs' => [ 'CelebrityRecognition$Celebrity' => '<p>Information about a recognized celebrity.</p>', ], ], 'CelebrityList' => [ 'base' => NULL, 'refs' => [ 'RecognizeCelebritiesResponse$CelebrityFaces' => '<p>Details about each celebrity found in the image. Amazon Rekognition can detect a maximum of 15 celebrities in an image.</p>', ], ], 'CelebrityRecognition' => [ 'base' => '<p>Information about a detected celebrity and the time the celebrity was detected in a stored video. For more information, see .</p>', 'refs' => [ 'CelebrityRecognitions$member' => NULL, ], ], 'CelebrityRecognitionSortBy' => [ 'base' => NULL, 'refs' => [ 'GetCelebrityRecognitionRequest$SortBy' => '<p>Sort to use for celebrities returned in <code>Celebrities</code> field. Specify <code>ID</code> to sort by the celebrity identifier, specify <code>TIMESTAMP</code> to sort by the time the celebrity was recognized.</p>', ], ], 'CelebrityRecognitions' => [ 'base' => NULL, 'refs' => [ 'GetCelebrityRecognitionResponse$Celebrities' => '<p>Array of celebrities recognized in the video.</p>', ], ], 'ClientRequestToken' => [ 'base' => NULL, 'refs' => [ 'StartCelebrityRecognitionRequest$ClientRequestToken' => '<p>Idempotent token used to identify the start request. If you use the same token with multiple <code>StartCelebrityRecognition</code> requests, the same <code>JobId</code> is returned. Use <code>ClientRequestToken</code> to prevent the same job from being accidently started more than once. </p>', 'StartContentModerationRequest$ClientRequestToken' => '<p>Idempotent token used to identify the start request. If you use the same token with multiple <code>StartContentModeration</code> requests, the same <code>JobId</code> is returned. Use <code>ClientRequestToken</code> to prevent the same job from being accidently started more than once. </p>', 'StartFaceDetectionRequest$ClientRequestToken' => '<p>Idempotent token used to identify the start request. If you use the same token with multiple <code>StartFaceDetection</code> requests, the same <code>JobId</code> is returned. Use <code>ClientRequestToken</code> to prevent the same job from being accidently started more than once. </p>', 'StartFaceSearchRequest$ClientRequestToken' => '<p>Idempotent token used to identify the start request. If you use the same token with multiple <code>StartFaceSearch</code> requests, the same <code>JobId</code> is returned. Use <code>ClientRequestToken</code> to prevent the same job from being accidently started more than once. </p>', 'StartLabelDetectionRequest$ClientRequestToken' => '<p>Idempotent token used to identify the start request. If you use the same token with multiple <code>StartLabelDetection</code> requests, the same <code>JobId</code> is returned. Use <code>ClientRequestToken</code> to prevent the same job from being accidently started more than once. </p>', 'StartPersonTrackingRequest$ClientRequestToken' => '<p>Idempotent token used to identify the start request. If you use the same token with multiple <code>StartPersonTracking</code> requests, the same <code>JobId</code> is returned. Use <code>ClientRequestToken</code> to prevent the same job from being accidently started more than once. </p>', ], ], 'CollectionId' => [ 'base' => NULL, 'refs' => [ 'CollectionIdList$member' => NULL, 'CreateCollectionRequest$CollectionId' => '<p>ID for the collection that you are creating.</p>', 'DeleteCollectionRequest$CollectionId' => '<p>ID of the collection to delete.</p>', 'DeleteFacesRequest$CollectionId' => '<p>Collection from which to remove the specific faces.</p>', 'FaceSearchSettings$CollectionId' => '<p>The ID of a collection that contains faces that you want to search for.</p>', 'IndexFacesRequest$CollectionId' => '<p>The ID of an existing collection to which you want to add the faces that are detected in the input images.</p>', 'ListFacesRequest$CollectionId' => '<p>ID of the collection from which to list the faces.</p>', 'SearchFacesByImageRequest$CollectionId' => '<p>ID of the collection to search.</p>', 'SearchFacesRequest$CollectionId' => '<p>ID of the collection the face belongs to.</p>', 'StartFaceSearchRequest$CollectionId' => '<p>ID of the collection that contains the faces you want to search for.</p>', ], ], 'CollectionIdList' => [ 'base' => NULL, 'refs' => [ 'ListCollectionsResponse$CollectionIds' => '<p>An array of collection IDs.</p>', ], ], 'CompareFacesMatch' => [ 'base' => '<p>Provides information about a face in a target image that matches the source image face analysed by <code>CompareFaces</code>. The <code>Face</code> property contains the bounding box of the face in the target image. The <code>Similarity</code> property is the confidence that the source image face matches the face in the bounding box.</p>', 'refs' => [ 'CompareFacesMatchList$member' => NULL, ], ], 'CompareFacesMatchList' => [ 'base' => NULL, 'refs' => [ 'CompareFacesResponse$FaceMatches' => '<p>An array of faces in the target image that match the source image face. Each <code>CompareFacesMatch</code> object provides the bounding box, the confidence level that the bounding box contains a face, and the similarity score for the face in the bounding box and the face in the source image.</p>', ], ], 'CompareFacesRequest' => [ 'base' => NULL, 'refs' => [], ], 'CompareFacesResponse' => [ 'base' => NULL, 'refs' => [], ], 'CompareFacesUnmatchList' => [ 'base' => NULL, 'refs' => [ 'CompareFacesResponse$UnmatchedFaces' => '<p>An array of faces in the target image that did not match the source image face.</p>', ], ], 'ComparedFace' => [ 'base' => '<p>Provides face metadata for target image faces that are analysed by <code>CompareFaces</code> and <code>RecognizeCelebrities</code>.</p>', 'refs' => [ 'Celebrity$Face' => '<p>Provides information about the celebrity\'s face, such as its location on the image.</p>', 'CompareFacesMatch$Face' => '<p>Provides face metadata (bounding box and confidence that the bounding box actually contains a face).</p>', 'CompareFacesUnmatchList$member' => NULL, 'ComparedFaceList$member' => NULL, ], ], 'ComparedFaceList' => [ 'base' => NULL, 'refs' => [ 'RecognizeCelebritiesResponse$UnrecognizedFaces' => '<p>Details about each unrecognized face in the image.</p>', ], ], 'ComparedSourceImageFace' => [ 'base' => '<p>Type that describes the face Amazon Rekognition chose to compare with the faces in the target. This contains a bounding box for the selected face and confidence level that the bounding box contains a face. Note that Amazon Rekognition selects the largest face in the source image for this comparison. </p>', 'refs' => [ 'CompareFacesResponse$SourceImageFace' => '<p>The face in the source image that was used for comparison.</p>', ], ], 'ContentModerationDetection' => [ 'base' => '<p>Information about a moderation label detection in a stored video.</p>', 'refs' => [ 'ContentModerationDetections$member' => NULL, ], ], 'ContentModerationDetections' => [ 'base' => NULL, 'refs' => [ 'GetContentModerationResponse$ModerationLabels' => '<p>The detected moderation labels and the time(s) they were detected.</p>', ], ], 'ContentModerationSortBy' => [ 'base' => NULL, 'refs' => [ 'GetContentModerationRequest$SortBy' => '<p>Sort to use for elements in the <code>ModerationLabelDetections</code> array. Use <code>TIMESTAMP</code> to sort array elements by the time labels are detected. Use <code>NAME</code> to alphabetically group elements for a label together. Within each label group, the array element are sorted by detection confidence. The default sort is by <code>TIMESTAMP</code>.</p>', ], ], 'CreateCollectionRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateCollectionResponse' => [ 'base' => NULL, 'refs' => [], ], 'CreateStreamProcessorRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateStreamProcessorResponse' => [ 'base' => NULL, 'refs' => [], ], 'DateTime' => [ 'base' => NULL, 'refs' => [ 'DescribeStreamProcessorResponse$CreationTimestamp' => '<p>Date and time the stream processor was created</p>', 'DescribeStreamProcessorResponse$LastUpdateTimestamp' => '<p>The time, in Unix format, the stream processor was last updated. For example, when the stream processor moves from a running state to a failed state, or when the user starts or stops the stream processor.</p>', ], ], 'Degree' => [ 'base' => NULL, 'refs' => [ 'Pose$Roll' => '<p>Value representing the face rotation on the roll axis.</p>', 'Pose$Yaw' => '<p>Value representing the face rotation on the yaw axis.</p>', 'Pose$Pitch' => '<p>Value representing the face rotation on the pitch axis.</p>', ], ], 'DeleteCollectionRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteCollectionResponse' => [ 'base' => NULL, 'refs' => [], ], 'DeleteFacesRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteFacesResponse' => [ 'base' => NULL, 'refs' => [], ], 'DeleteStreamProcessorRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteStreamProcessorResponse' => [ 'base' => NULL, 'refs' => [], ], 'DescribeStreamProcessorRequest' => [ 'base' => NULL, 'refs' => [], ], 'DescribeStreamProcessorResponse' => [ 'base' => NULL, 'refs' => [], ], 'DetectFacesRequest' => [ 'base' => NULL, 'refs' => [], ], 'DetectFacesResponse' => [ 'base' => NULL, 'refs' => [], ], 'DetectLabelsRequest' => [ 'base' => NULL, 'refs' => [], ], 'DetectLabelsResponse' => [ 'base' => NULL, 'refs' => [], ], 'DetectModerationLabelsRequest' => [ 'base' => NULL, 'refs' => [], ], 'DetectModerationLabelsResponse' => [ 'base' => NULL, 'refs' => [], ], 'DetectTextRequest' => [ 'base' => NULL, 'refs' => [], ], 'DetectTextResponse' => [ 'base' => NULL, 'refs' => [], ], 'Emotion' => [ 'base' => '<p>The emotions detected on the face, and the confidence level in the determination. For example, HAPPY, SAD, and ANGRY.</p>', 'refs' => [ 'Emotions$member' => NULL, ], ], 'EmotionName' => [ 'base' => NULL, 'refs' => [ 'Emotion$Type' => '<p>Type of emotion detected.</p>', ], ], 'Emotions' => [ 'base' => NULL, 'refs' => [ 'FaceDetail$Emotions' => '<p>The emotions detected on the face, and the confidence level in the determination. For example, HAPPY, SAD, and ANGRY. </p>', ], ], 'ExternalImageId' => [ 'base' => NULL, 'refs' => [ 'Face$ExternalImageId' => '<p>Identifier that you assign to all the faces in the input image.</p>', 'IndexFacesRequest$ExternalImageId' => '<p>ID you want to assign to all the faces detected in the image.</p>', ], ], 'EyeOpen' => [ 'base' => '<p>Indicates whether or not the eyes on the face are open, and the confidence level in the determination.</p>', 'refs' => [ 'FaceDetail$EyesOpen' => '<p>Indicates whether or not the eyes on the face are open, and the confidence level in the determination.</p>', ], ], 'Eyeglasses' => [ 'base' => '<p>Indicates whether or not the face is wearing eye glasses, and the confidence level in the determination.</p>', 'refs' => [ 'FaceDetail$Eyeglasses' => '<p>Indicates whether or not the face is wearing eye glasses, and the confidence level in the determination.</p>', ], ], 'Face' => [ 'base' => '<p>Describes the face properties such as the bounding box, face ID, image ID of the input image, and external image ID that you assigned. </p>', 'refs' => [ 'FaceList$member' => NULL, 'FaceMatch$Face' => '<p>Describes the face properties such as the bounding box, face ID, image ID of the source image, and external image ID that you assigned.</p>', 'FaceRecord$Face' => '<p>Describes the face properties such as the bounding box, face ID, image ID of the input image, and external image ID that you assigned. </p>', ], ], 'FaceAttributes' => [ 'base' => NULL, 'refs' => [ 'StartFaceDetectionRequest$FaceAttributes' => '<p>The face attributes you want returned.</p> <p> <code>DEFAULT</code> - The following subset of facial attributes are returned: BoundingBox, Confidence, Pose, Quality and Landmarks. </p> <p> <code>ALL</code> - All facial attributes are returned.</p>', ], ], 'FaceDetail' => [ 'base' => '<p>Structure containing attributes of the face that the algorithm detected.</p>', 'refs' => [ 'CelebrityDetail$Face' => '<p>Face details for the recognized celebrity.</p>', 'FaceDetailList$member' => NULL, 'FaceDetection$Face' => '<p>The face properties for the detected face.</p>', 'FaceRecord$FaceDetail' => '<p>Structure containing attributes of the face that the algorithm detected.</p>', 'PersonDetail$Face' => '<p>Face details for the detected person.</p>', ], ], 'FaceDetailList' => [ 'base' => NULL, 'refs' => [ 'DetectFacesResponse$FaceDetails' => '<p>Details of each face found in the image. </p>', ], ], 'FaceDetection' => [ 'base' => '<p>Information about a face detected in a video analysis request and the time the face was detected in the video. </p>', 'refs' => [ 'FaceDetections$member' => NULL, ], ], 'FaceDetections' => [ 'base' => NULL, 'refs' => [ 'GetFaceDetectionResponse$Faces' => '<p>An array of faces detected in the video. Each element contains a detected face\'s details and the time, in milliseconds from the start of the video, the face was detected. </p>', ], ], 'FaceId' => [ 'base' => NULL, 'refs' => [ 'Face$FaceId' => '<p>Unique identifier that Amazon Rekognition assigns to the face.</p>', 'FaceIdList$member' => NULL, 'SearchFacesRequest$FaceId' => '<p>ID of a face to find matches for in the collection.</p>', 'SearchFacesResponse$SearchedFaceId' => '<p>ID of the face that was searched for matches in a collection.</p>', ], ], 'FaceIdList' => [ 'base' => NULL, 'refs' => [ 'DeleteFacesRequest$FaceIds' => '<p>An array of face IDs to delete.</p>', 'DeleteFacesResponse$DeletedFaces' => '<p>An array of strings (face IDs) of the faces that were deleted.</p>', ], ], 'FaceList' => [ 'base' => NULL, 'refs' => [ 'ListFacesResponse$Faces' => '<p>An array of <code>Face</code> objects. </p>', ], ], 'FaceMatch' => [ 'base' => '<p>Provides face metadata. In addition, it also provides the confidence in the match of this face with the input face.</p>', 'refs' => [ 'FaceMatchList$member' => NULL, ], ], 'FaceMatchList' => [ 'base' => NULL, 'refs' => [ 'PersonMatch$FaceMatches' => '<p>Information about the faces in the input collection that match the face of a person in the video.</p>', 'SearchFacesByImageResponse$FaceMatches' => '<p>An array of faces that match the input face, along with the confidence in the match.</p>', 'SearchFacesResponse$FaceMatches' => '<p>An array of faces that matched the input face, along with the confidence in the match.</p>', ], ], 'FaceModelVersionList' => [ 'base' => NULL, 'refs' => [ 'ListCollectionsResponse$FaceModelVersions' => '<p>Version numbers of the face detection models associated with the collections in the array <code>CollectionIds</code>. For example, the value of <code>FaceModelVersions[2]</code> is the version number for the face detection model used by the collection in <code>CollectionId[2]</code>.</p>', ], ], 'FaceRecord' => [ 'base' => '<p>Object containing both the face metadata (stored in the back-end database) and facial attributes that are detected but aren\'t stored in the database.</p>', 'refs' => [ 'FaceRecordList$member' => NULL, ], ], 'FaceRecordList' => [ 'base' => NULL, 'refs' => [ 'IndexFacesResponse$FaceRecords' => '<p>An array of faces detected and added to the collection. For more information, see <a>collections-index-faces</a>. </p>', ], ], 'FaceSearchSettings' => [ 'base' => '<p>Input face recognition parameters for an Amazon Rekognition stream processor. <code>FaceRecognitionSettings</code> is a request parameter for .</p>', 'refs' => [ 'StreamProcessorSettings$FaceSearch' => '<p>Face search settings to use on a streaming video. </p>', ], ], 'FaceSearchSortBy' => [ 'base' => NULL, 'refs' => [ 'GetFaceSearchRequest$SortBy' => '<p>Sort to use for grouping faces in the response. Use <code>TIMESTAMP</code> to group faces by the time that they are recognized. Use <code>INDEX</code> to sort by recognized faces. </p>', ], ], 'Float' => [ 'base' => NULL, 'refs' => [ 'BoundingBox$Width' => '<p>Width of the bounding box as a ratio of the overall image width.</p>', 'BoundingBox$Height' => '<p>Height of the bounding box as a ratio of the overall image height.</p>', 'BoundingBox$Left' => '<p>Left coordinate of the bounding box as a ratio of overall image width.</p>', 'BoundingBox$Top' => '<p>Top coordinate of the bounding box as a ratio of overall image height.</p>', 'ImageQuality$Brightness' => '<p>Value representing brightness of the face. The service returns a value between 0 and 100 (inclusive). A higher value indicates a brighter face image.</p>', 'ImageQuality$Sharpness' => '<p>Value representing sharpness of the face. The service returns a value between 0 and 100 (inclusive). A higher value indicates a sharper face image.</p>', 'Landmark$X' => '<p>x-coordinate from the top left of the landmark expressed as the ratio of the width of the image. For example, if the images is 700x200 and the x-coordinate of the landmark is at 350 pixels, this value is 0.5. </p>', 'Landmark$Y' => '<p>y-coordinate from the top left of the landmark expressed as the ratio of the height of the image. For example, if the images is 700x200 and the y-coordinate of the landmark is at 100 pixels, this value is 0.5.</p>', 'Point$X' => '<p>The value of the X coordinate for a point on a <code>Polygon</code>.</p>', 'Point$Y' => '<p>The value of the Y coordinate for a point on a <code>Polygon</code>.</p>', 'VideoMetadata$FrameRate' => '<p>Number of frames per second in the video.</p>', ], ], 'Gender' => [ 'base' => '<p>Gender of the face and the confidence level in the determination.</p>', 'refs' => [ 'FaceDetail$Gender' => '<p>Gender of the face and the confidence level in the determination.</p>', ], ], 'GenderType' => [ 'base' => NULL, 'refs' => [ 'Gender$Value' => '<p>Gender of the face.</p>', ], ], 'Geometry' => [ 'base' => '<p>Information about where text detected by is located on an image.</p>', 'refs' => [ 'TextDetection$Geometry' => '<p>The location of the detected text on the image. Includes an axis aligned coarse bounding box surrounding the text and a finer grain polygon for more accurate spatial information.</p>', ], ], 'GetCelebrityInfoRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetCelebrityInfoResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetCelebrityRecognitionRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetCelebrityRecognitionResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetContentModerationRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetContentModerationResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetFaceDetectionRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetFaceDetectionResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetFaceSearchRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetFaceSearchResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetLabelDetectionRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetLabelDetectionResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetPersonTrackingRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetPersonTrackingResponse' => [ 'base' => NULL, 'refs' => [], ], 'IdempotentParameterMismatchException' => [ 'base' => '<p>A <code>ClientRequestToken</code> input parameter was reused with an operation, but at least one of the other input parameters is different from the previous call to the operation.</p>', 'refs' => [], ], 'Image' => [ 'base' => '<p>Provides the input image either as bytes or an S3 object.</p> <p>You pass image bytes to a Rekognition API operation by using the <code>Bytes</code> property. For example, you would use the <code>Bytes</code> property to pass an image loaded from a local file system. Image bytes passed by using the <code>Bytes</code> property must be base64-encoded. Your code may not need to encode image bytes if you are using an AWS SDK to call Rekognition API operations. For more information, see <a>images-bytes</a>.</p> <p> You pass images stored in an S3 bucket to a Rekognition API operation by using the <code>S3Object</code> property. Images stored in an S3 bucket do not need to be base64-encoded.</p> <p>The region for the S3 bucket containing the S3 object must match the region you use for Amazon Rekognition operations.</p> <p>If you use the Amazon CLI to call Amazon Rekognition operations, passing image bytes using the Bytes property is not supported. You must first upload the image to an Amazon S3 bucket and then call the operation using the S3Object property.</p> <p>For Amazon Rekognition to process an S3 object, the user must have permission to access the S3 object. For more information, see <a>manage-access-resource-policies</a>. </p>', 'refs' => [ 'CompareFacesRequest$SourceImage' => '<p>The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported. </p>', 'CompareFacesRequest$TargetImage' => '<p>The target image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported. </p>', 'DetectFacesRequest$Image' => '<p>The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported. </p>', 'DetectLabelsRequest$Image' => '<p>The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported. </p>', 'DetectModerationLabelsRequest$Image' => '<p>The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported. </p>', 'DetectTextRequest$Image' => '<p>The input image as base64-encoded bytes or an Amazon S3 object. If you use the AWS CLI to call Amazon Rekognition operations, you can\'t pass image bytes. </p>', 'IndexFacesRequest$Image' => '<p>The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported. </p>', 'RecognizeCelebritiesRequest$Image' => '<p>The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported. </p>', 'SearchFacesByImageRequest$Image' => '<p>The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported. </p>', ], ], 'ImageBlob' => [ 'base' => NULL, 'refs' => [ 'Image$Bytes' => '<p>Blob of image bytes up to 5 MBs.</p>', ], ], 'ImageId' => [ 'base' => NULL, 'refs' => [ 'Face$ImageId' => '<p>Unique identifier that Amazon Rekognition assigns to the input image.</p>', ], ], 'ImageQuality' => [ 'base' => '<p>Identifies face image brightness and sharpness. </p>', 'refs' => [ 'ComparedFace$Quality' => '<p>Identifies face image brightness and sharpness. </p>', 'FaceDetail$Quality' => '<p>Identifies image brightness and sharpness.</p>', ], ], 'ImageTooLargeException' => [ 'base' => '<p>The input image size exceeds the allowed limit. For more information, see <a>limits</a>. </p>', 'refs' => [], ], 'IndexFacesRequest' => [ 'base' => NULL, 'refs' => [], ], 'IndexFacesResponse' => [ 'base' => NULL, 'refs' => [], ], 'InternalServerError' => [ 'base' => '<p>Amazon Rekognition experienced a service issue. Try your call again.</p>', 'refs' => [], ], 'InvalidImageFormatException' => [ 'base' => '<p>The provided image format is not supported. </p>', 'refs' => [], ], 'InvalidPaginationTokenException' => [ 'base' => '<p>Pagination token in the request is not valid.</p>', 'refs' => [], ], 'InvalidParameterException' => [ 'base' => '<p>Input parameter violated a constraint. Validate your parameter before calling the API operation again.</p>', 'refs' => [], ], 'InvalidS3ObjectException' => [ 'base' => '<p>Amazon Rekognition is unable to access the S3 object specified in the request.</p>', 'refs' => [], ], 'JobId' => [ 'base' => NULL, 'refs' => [ 'GetCelebrityRecognitionRequest$JobId' => '<p>Job identifier for the required celebrity recognition analysis. You can get the job identifer from a call to <code>StartCelebrityRecognition</code>.</p>', 'GetContentModerationRequest$JobId' => '<p>The identifier for the content moderation job. Use <code>JobId</code> to identify the job in a subsequent call to <code>GetContentModeration</code>.</p>', 'GetFaceDetectionRequest$JobId' => '<p>Unique identifier for the face detection job. The <code>JobId</code> is returned from <code>StartFaceDetection</code>.</p>', 'GetFaceSearchRequest$JobId' => '<p>The job identifer for the search request. You get the job identifier from an initial call to <code>StartFaceSearch</code>.</p>', 'GetLabelDetectionRequest$JobId' => '<p>Job identifier for the label detection operation for which you want results returned. You get the job identifer from an initial call to <code>StartlabelDetection</code>.</p>', 'GetPersonTrackingRequest$JobId' => '<p>The identifier for a job that tracks persons in a video. You get the <code>JobId</code> from a call to <code>StartPersonTracking</code>. </p>', 'StartCelebrityRecognitionResponse$JobId' => '<p>The identifier for the celebrity recognition analysis job. Use <code>JobId</code> to identify the job in a subsequent call to <code>GetCelebrityRecognition</code>.</p>', 'StartContentModerationResponse$JobId' => '<p>The identifier for the content moderation analysis job. Use <code>JobId</code> to identify the job in a subsequent call to <code>GetContentModeration</code>.</p>', 'StartFaceDetectionResponse$JobId' => '<p>The identifier for the face detection job. Use <code>JobId</code> to identify the job in a subsequent call to <code>GetFaceDetection</code>.</p>', 'StartFaceSearchResponse$JobId' => '<p>The identifier for the search job. Use <code>JobId</code> to identify the job in a subsequent call to <code>GetFaceSearch</code>. </p>', 'StartLabelDetectionResponse$JobId' => '<p>The identifier for the label detection job. Use <code>JobId</code> to identify the job in a subsequent call to <code>GetLabelDetection</code>. </p>', 'StartPersonTrackingResponse$JobId' => '<p>The identifier for the person detection job. Use <code>JobId</code> to identify the job in a subsequent call to <code>GetPersonTracking</code>.</p>', ], ], 'JobTag' => [ 'base' => NULL, 'refs' => [ 'StartCelebrityRecognitionRequest$JobTag' => '<p>Unique identifier you specify to identify the job in the completion status published to the Amazon Simple Notification Service topic. </p>', 'StartContentModerationRequest$JobTag' => '<p>Unique identifier you specify to identify the job in the completion status published to the Amazon Simple Notification Service topic. </p>', 'StartFaceDetectionRequest$JobTag' => '<p>Unique identifier you specify to identify the job in the completion status published to the Amazon Simple Notification Service topic. </p>', 'StartFaceSearchRequest$JobTag' => '<p>Unique identifier you specify to identify the job in the completion status published to the Amazon Simple Notification Service topic. </p>', 'StartLabelDetectionRequest$JobTag' => '<p>Unique identifier you specify to identify the job in the completion status published to the Amazon Simple Notification Service topic. </p>', 'StartPersonTrackingRequest$JobTag' => '<p>Unique identifier you specify to identify the job in the completion status published to the Amazon Simple Notification Service topic. </p>', ], ], 'KinesisDataArn' => [ 'base' => NULL, 'refs' => [ 'KinesisDataStream$Arn' => '<p>ARN of the output Amazon Kinesis Data Streams stream.</p>', ], ], 'KinesisDataStream' => [ 'base' => '<p>The Kinesis data stream Amazon Rekognition to which the analysis results of a Amazon Rekognition stream processor are streamed. For more information, see .</p>', 'refs' => [ 'StreamProcessorOutput$KinesisDataStream' => '<p>The Amazon Kinesis Data Streams stream to which the Amazon Rekognition stream processor streams the analysis results.</p>', ], ], 'KinesisVideoArn' => [ 'base' => NULL, 'refs' => [ 'KinesisVideoStream$Arn' => '<p>ARN of the Kinesis video stream stream that streams the source video.</p>', ], ], 'KinesisVideoStream' => [ 'base' => '<p>Kinesis video stream stream that provides the source streaming video for a Rekognition Video stream processor. For more information, see .</p>', 'refs' => [ 'StreamProcessorInput$KinesisVideoStream' => '<p>The Kinesis video stream input stream for the source streaming video.</p>', ], ], 'Label' => [ 'base' => '<p>Structure containing details about the detected label, including name, and level of confidence.</p>', 'refs' => [ 'LabelDetection$Label' => '<p>Details about the detected label.</p>', 'Labels$member' => NULL, ], ], 'LabelDetection' => [ 'base' => '<p>Information about a label detected in a video analysis request and the time the label was detected in the video. </p>', 'refs' => [ 'LabelDetections$member' => NULL, ], ], 'LabelDetectionSortBy' => [ 'base' => NULL, 'refs' => [ 'GetLabelDetectionRequest$SortBy' => '<p>Sort to use for elements in the <code>Labels</code> array. Use <code>TIMESTAMP</code> to sort array elements by the time labels are detected. Use <code>NAME</code> to alphabetically group elements for a label together. Within each label group, the array element are sorted by detection confidence. The default sort is by <code>TIMESTAMP</code>.</p>', ], ], 'LabelDetections' => [ 'base' => NULL, 'refs' => [ 'GetLabelDetectionResponse$Labels' => '<p>An array of labels detected in the video. Each element contains the detected label and the time, in milliseconds from the start of the video, that the label was detected. </p>', ], ], 'Labels' => [ 'base' => NULL, 'refs' => [ 'DetectLabelsResponse$Labels' => '<p>An array of labels for the real-world objects detected. </p>', ], ], 'Landmark' => [ 'base' => '<p>Indicates the location of the landmark on the face.</p>', 'refs' => [ 'Landmarks$member' => NULL, ], ], 'LandmarkType' => [ 'base' => NULL, 'refs' => [ 'Landmark$Type' => '<p>Type of the landmark.</p>', ], ], 'Landmarks' => [ 'base' => NULL, 'refs' => [ 'ComparedFace$Landmarks' => '<p>An array of facial landmarks.</p>', 'FaceDetail$Landmarks' => '<p>Indicates the location of landmarks on the face.</p>', ], ], 'LimitExceededException' => [ 'base' => '<p/>', 'refs' => [], ], 'ListCollectionsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListCollectionsResponse' => [ 'base' => NULL, 'refs' => [], ], 'ListFacesRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListFacesResponse' => [ 'base' => NULL, 'refs' => [], ], 'ListStreamProcessorsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListStreamProcessorsResponse' => [ 'base' => NULL, 'refs' => [], ], 'MaxFaces' => [ 'base' => NULL, 'refs' => [ 'SearchFacesByImageRequest$MaxFaces' => '<p>Maximum number of faces to return. The operation returns the maximum number of faces with the highest confidence in the match.</p>', 'SearchFacesRequest$MaxFaces' => '<p>Maximum number of faces to return. The operation returns the maximum number of faces with the highest confidence in the match.</p>', ], ], 'MaxResults' => [ 'base' => NULL, 'refs' => [ 'GetCelebrityRecognitionRequest$MaxResults' => '<p>Maximum number of celebrities you want Rekognition Video to return in the response. The default is 1000.</p>', 'GetContentModerationRequest$MaxResults' => '<p>Maximum number of content moderation labels to return. The default is 1000.</p>', 'GetFaceDetectionRequest$MaxResults' => '<p>Maximum number of detected faces to return. The default is 1000.</p>', 'GetFaceSearchRequest$MaxResults' => '<p>Maximum number of search results you want Rekognition Video to return in the response. The default is 1000.</p>', 'GetLabelDetectionRequest$MaxResults' => '<p>Maximum number of labels you want Amazon Rekognition to return in the response. The default is 1000.</p>', 'GetPersonTrackingRequest$MaxResults' => '<p>Maximum number of tracked persons to return. The default is 1000. </p>', 'ListStreamProcessorsRequest$MaxResults' => '<p>Maximum number of stream processors you want Rekognition Video to return in the response. The default is 1000. </p>', ], ], 'ModerationLabel' => [ 'base' => '<p>Provides information about a single type of moderated content found in an image or video. Each type of moderated content has a label within a hierarchical taxonomy. For more information, see <a>moderation</a>.</p>', 'refs' => [ 'ContentModerationDetection$ModerationLabel' => '<p>The moderation label detected by in the stored video.</p>', 'ModerationLabels$member' => NULL, ], ], 'ModerationLabels' => [ 'base' => NULL, 'refs' => [ 'DetectModerationLabelsResponse$ModerationLabels' => '<p>Array of detected Moderation labels and the time, in millseconds from the start of the video, they were detected.</p>', ], ], 'MouthOpen' => [ 'base' => '<p>Indicates whether or not the mouth on the face is open, and the confidence level in the determination.</p>', 'refs' => [ 'FaceDetail$MouthOpen' => '<p>Indicates whether or not the mouth on the face is open, and the confidence level in the determination.</p>', ], ], 'Mustache' => [ 'base' => '<p>Indicates whether or not the face has a mustache, and the confidence level in the determination.</p>', 'refs' => [ 'FaceDetail$Mustache' => '<p>Indicates whether or not the face has a mustache, and the confidence level in the determination.</p>', ], ], 'NotificationChannel' => [ 'base' => '<p>The Amazon Simple Notification Service topic to which Amazon Rekognition publishes the completion status of a video analysis operation. For more information, see <a>api-video</a>.</p>', 'refs' => [ 'StartCelebrityRecognitionRequest$NotificationChannel' => '<p>The Amazon SNS topic ARN that you want Rekognition Video to publish the completion status of the celebrity recognition analysis to.</p>', 'StartContentModerationRequest$NotificationChannel' => '<p>The Amazon SNS topic ARN that you want Rekognition Video to publish the completion status of the content moderation analysis to.</p>', 'StartFaceDetectionRequest$NotificationChannel' => '<p>The ARN of the Amazon SNS topic to which you want Rekognition Video to publish the completion status of the face detection operation.</p>', 'StartFaceSearchRequest$NotificationChannel' => '<p>The ARN of the Amazon SNS topic to which you want Rekognition Video to publish the completion status of the search. </p>', 'StartLabelDetectionRequest$NotificationChannel' => '<p>The Amazon SNS topic ARN you want Rekognition Video to publish the completion status of the label detection operation to. </p>', 'StartPersonTrackingRequest$NotificationChannel' => '<p>The Amazon SNS topic ARN you want Rekognition Video to publish the completion status of the people detection operation to.</p>', ], ], 'OrientationCorrection' => [ 'base' => NULL, 'refs' => [ 'CompareFacesResponse$SourceImageOrientationCorrection' => '<p> The orientation of the source image (counterclockwise direction). If your application displays the source image, you can use this value to correct image orientation. The bounding box coordinates returned in <code>SourceImageFace</code> represent the location of the face before the image orientation is corrected. </p> <note> <p>If the source image is in .jpeg format, it might contain exchangeable image (Exif) metadata that includes the image\'s orientation. If the Exif metadata for the source image populates the orientation field, the value of <code>OrientationCorrection</code> is null and the <code>SourceImageFace</code> bounding box coordinates represent the location of the face after Exif metadata is used to correct the orientation. Images in .png format don\'t contain Exif metadata.</p> </note>', 'CompareFacesResponse$TargetImageOrientationCorrection' => '<p> The orientation of the target image (in counterclockwise direction). If your application displays the target image, you can use this value to correct the orientation of the image. The bounding box coordinates returned in <code>FaceMatches</code> and <code>UnmatchedFaces</code> represent face locations before the image orientation is corrected. </p> <note> <p>If the target image is in .jpg format, it might contain Exif metadata that includes the orientation of the image. If the Exif metadata for the target image populates the orientation field, the value of <code>OrientationCorrection</code> is null and the bounding box coordinates in <code>FaceMatches</code> and <code>UnmatchedFaces</code> represent the location of the face after Exif metadata is used to correct the orientation. Images in .png format don\'t contain Exif metadata.</p> </note>', 'DetectFacesResponse$OrientationCorrection' => '<p> The orientation of the input image (counter-clockwise direction). If your application displays the image, you can use this value to correct image orientation. The bounding box coordinates returned in <code>FaceDetails</code> represent face locations before the image orientation is corrected. </p> <note> <p>If the input image is in .jpeg format, it might contain exchangeable image (Exif) metadata that includes the image\'s orientation. If so, and the Exif metadata for the input image populates the orientation field, the value of <code>OrientationCorrection</code> is null and the <code>FaceDetails</code> bounding box coordinates represent face locations after Exif metadata is used to correct the image orientation. Images in .png format don\'t contain Exif metadata.</p> </note>', 'DetectLabelsResponse$OrientationCorrection' => '<p> The orientation of the input image (counter-clockwise direction). If your application displays the image, you can use this value to correct the orientation. If Amazon Rekognition detects that the input image was rotated (for example, by 90 degrees), it first corrects the orientation before detecting the labels. </p> <note> <p>If the input image Exif metadata populates the orientation field, Amazon Rekognition does not perform orientation correction and the value of OrientationCorrection will be null.</p> </note>', 'IndexFacesResponse$OrientationCorrection' => '<p>The orientation of the input image (counterclockwise direction). If your application displays the image, you can use this value to correct image orientation. The bounding box coordinates returned in <code>FaceRecords</code> represent face locations before the image orientation is corrected. </p> <note> <p>If the input image is in jpeg format, it might contain exchangeable image (Exif) metadata. If so, and the Exif metadata populates the orientation field, the value of <code>OrientationCorrection</code> is null and the bounding box coordinates in <code>FaceRecords</code> represent face locations after Exif metadata is used to correct the image orientation. Images in .png format don\'t contain Exif metadata.</p> </note>', 'RecognizeCelebritiesResponse$OrientationCorrection' => '<p>The orientation of the input image (counterclockwise direction). If your application displays the image, you can use this value to correct the orientation. The bounding box coordinates returned in <code>CelebrityFaces</code> and <code>UnrecognizedFaces</code> represent face locations before the image orientation is corrected. </p> <note> <p>If the input image is in .jpeg format, it might contain exchangeable image (Exif) metadata that includes the image\'s orientation. If so, and the Exif metadata for the input image populates the orientation field, the value of <code>OrientationCorrection</code> is null and the <code>CelebrityFaces</code> and <code>UnrecognizedFaces</code> bounding box coordinates represent face locations after Exif metadata is used to correct the image orientation. Images in .png format don\'t contain Exif metadata. </p> </note>', ], ], 'PageSize' => [ 'base' => NULL, 'refs' => [ 'ListCollectionsRequest$MaxResults' => '<p>Maximum number of collection IDs to return. </p>', 'ListFacesRequest$MaxResults' => '<p>Maximum number of faces to return.</p>', ], ], 'PaginationToken' => [ 'base' => NULL, 'refs' => [ 'GetCelebrityRecognitionRequest$NextToken' => '<p>If the previous response was incomplete (because there is more recognized celebrities to retrieve), Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of celebrities. </p>', 'GetCelebrityRecognitionResponse$NextToken' => '<p>If the response is truncated, Rekognition Video returns this token that you can use in the subsequent request to retrieve the next set of celebrities.</p>', 'GetContentModerationRequest$NextToken' => '<p>If the previous response was incomplete (because there is more data to retrieve), Amazon Rekognition returns a pagination token in the response. You can use this pagination token to retrieve the next set of content moderation labels.</p>', 'GetContentModerationResponse$NextToken' => '<p>If the response is truncated, Rekognition Video returns this token that you can use in the subsequent request to retrieve the next set of moderation labels. </p>', 'GetFaceDetectionRequest$NextToken' => '<p>If the previous response was incomplete (because there are more faces to retrieve), Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of faces.</p>', 'GetFaceDetectionResponse$NextToken' => '<p>If the response is truncated, Amazon Rekognition returns this token that you can use in the subsequent request to retrieve the next set of faces. </p>', 'GetFaceSearchRequest$NextToken' => '<p>If the previous response was incomplete (because there is more search results to retrieve), Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of search results. </p>', 'GetFaceSearchResponse$NextToken' => '<p>If the response is truncated, Rekognition Video returns this token that you can use in the subsequent request to retrieve the next set of search results. </p>', 'GetLabelDetectionRequest$NextToken' => '<p>If the previous response was incomplete (because there are more labels to retrieve), Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of labels. </p>', 'GetLabelDetectionResponse$NextToken' => '<p>If the response is truncated, Rekognition Video returns this token that you can use in the subsequent request to retrieve the next set of labels.</p>', 'GetPersonTrackingRequest$NextToken' => '<p>If the previous response was incomplete (because there are more persons to retrieve), Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of persons. </p>', 'GetPersonTrackingResponse$NextToken' => '<p>If the response is truncated, Rekognition Video returns this token that you can use in the subsequent request to retrieve the next set of persons. </p>', 'ListCollectionsRequest$NextToken' => '<p>Pagination token from the previous response.</p>', 'ListCollectionsResponse$NextToken' => '<p>If the result is truncated, the response provides a <code>NextToken</code> that you can use in the subsequent request to fetch the next set of collection IDs.</p>', 'ListFacesRequest$NextToken' => '<p>If the previous response was incomplete (because there is more data to retrieve), Amazon Rekognition returns a pagination token in the response. You can use this pagination token to retrieve the next set of faces.</p>', 'ListStreamProcessorsRequest$NextToken' => '<p>If the previous response was incomplete (because there are more stream processors to retrieve), Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of stream processors. </p>', 'ListStreamProcessorsResponse$NextToken' => '<p>If the response is truncated, Rekognition Video returns this token that you can use in the subsequent request to retrieve the next set of stream processors. </p>', ], ], 'Percent' => [ 'base' => NULL, 'refs' => [ 'Beard$Confidence' => '<p>Level of confidence in the determination.</p>', 'Celebrity$MatchConfidence' => '<p>The confidence, in percentage, that Rekognition has that the recognized face is the celebrity.</p>', 'CelebrityDetail$Confidence' => '<p>The confidence, in percentage, that Amazon Rekognition has that the recognized face is the celebrity. </p>', 'CompareFacesMatch$Similarity' => '<p>Level of confidence that the faces match.</p>', 'CompareFacesRequest$SimilarityThreshold' => '<p>The minimum level of confidence in the face matches that a match must meet to be included in the <code>FaceMatches</code> array.</p>', 'ComparedFace$Confidence' => '<p>Level of confidence that what the bounding box contains is a face.</p>', 'ComparedSourceImageFace$Confidence' => '<p>Confidence level that the selected bounding box contains a face.</p>', 'DetectLabelsRequest$MinConfidence' => '<p>Specifies the minimum confidence level for the labels to return. Amazon Rekognition doesn\'t return any labels with confidence lower than this specified value.</p> <p>If <code>MinConfidence</code> is not specified, the operation returns labels with a confidence values greater than or equal to 50 percent.</p>', 'DetectModerationLabelsRequest$MinConfidence' => '<p>Specifies the minimum confidence level for the labels to return. Amazon Rekognition doesn\'t return any labels with a confidence level lower than this specified value.</p> <p>If you don\'t specify <code>MinConfidence</code>, the operation returns labels with confidence values greater than or equal to 50 percent.</p>', 'Emotion$Confidence' => '<p>Level of confidence in the determination.</p>', 'EyeOpen$Confidence' => '<p>Level of confidence in the determination.</p>', 'Eyeglasses$Confidence' => '<p>Level of confidence in the determination.</p>', 'Face$Confidence' => '<p>Confidence level that the bounding box contains a face (and not a different object such as a tree).</p>', 'FaceDetail$Confidence' => '<p>Confidence level that the bounding box contains a face (and not a different object such as a tree).</p>', 'FaceMatch$Similarity' => '<p>Confidence in the match of this face with the input face.</p>', 'FaceSearchSettings$FaceMatchThreshold' => '<p>Minimum face match confidence score that must be met to return a result for a recognized face. Default is 70. 0 is the lowest confidence. 100 is the highest confidence.</p>', 'Gender$Confidence' => '<p>Level of confidence in the determination.</p>', 'Label$Confidence' => '<p>Level of confidence.</p>', 'ModerationLabel$Confidence' => '<p>Specifies the confidence that Amazon Rekognition has that the label has been correctly identified.</p> <p>If you don\'t specify the <code>MinConfidence</code> parameter in the call to <code>DetectModerationLabels</code>, the operation returns labels with a confidence value greater than or equal to 50 percent.</p>', 'MouthOpen$Confidence' => '<p>Level of confidence in the determination.</p>', 'Mustache$Confidence' => '<p>Level of confidence in the determination.</p>', 'SearchFacesByImageRequest$FaceMatchThreshold' => '<p>(Optional) Specifies the minimum confidence in the face match to return. For example, don\'t return any matches where confidence in matches is less than 70%.</p>', 'SearchFacesByImageResponse$SearchedFaceConfidence' => '<p>The level of confidence that the <code>searchedFaceBoundingBox</code>, contains a face.</p>', 'SearchFacesRequest$FaceMatchThreshold' => '<p>Optional value specifying the minimum confidence in the face match to return. For example, don\'t return any matches where confidence in matches is less than 70%.</p>', 'Smile$Confidence' => '<p>Level of confidence in the determination.</p>', 'StartContentModerationRequest$MinConfidence' => '<p>Specifies the minimum confidence that Amazon Rekognition must have in order to return a moderated content label. Confidence represents how certain Amazon Rekognition is that the moderated content is correctly identified. 0 is the lowest confidence. 100 is the highest confidence. Amazon Rekognition doesn\'t return any moderated content labels with a confidence level lower than this specified value.</p>', 'StartFaceSearchRequest$FaceMatchThreshold' => '<p>The minimum confidence in the person match to return. For example, don\'t return any matches where confidence in matches is less than 70%. </p>', 'StartLabelDetectionRequest$MinConfidence' => '<p>Specifies the minimum confidence that Rekognition Video must have in order to return a detected label. Confidence represents how certain Amazon Rekognition is that a label is correctly identified.0 is the lowest confidence. 100 is the highest confidence. Rekognition Video doesn\'t return any labels with a confidence level lower than this specified value.</p> <p>If you don\'t specify <code>MinConfidence</code>, the operation returns labels with confidence values greater than or equal to 50 percent.</p>', 'Sunglasses$Confidence' => '<p>Level of confidence in the determination.</p>', 'TextDetection$Confidence' => '<p>The confidence that Amazon Rekognition has in the accuracy of the detected text and the accuracy of the geometry points around the detected text.</p>', ], ], 'PersonDetail' => [ 'base' => '<p>Details about a person detected in a video analysis request.</p>', 'refs' => [ 'PersonDetection$Person' => '<p>Details about a person tracked in a video.</p>', 'PersonMatch$Person' => '<p>Information about the matched person.</p>', ], ], 'PersonDetection' => [ 'base' => '<p>Details and tracking information for a single time a person is tracked in a video. Amazon Rekognition operations that track persons return an array of <code>PersonDetection</code> objects with elements for each time a person is tracked in a video. For more information, see . </p>', 'refs' => [ 'PersonDetections$member' => NULL, ], ], 'PersonDetections' => [ 'base' => NULL, 'refs' => [ 'GetPersonTrackingResponse$Persons' => '<p>An array of the persons detected in the video and the times they are tracked throughout the video. An array element will exist for each time the person is tracked. </p>', ], ], 'PersonIndex' => [ 'base' => NULL, 'refs' => [ 'PersonDetail$Index' => '<p>Identifier for the person detected person within a video. Use to keep track of the person throughout the video. The identifier is not stored by Amazon Rekognition.</p>', ], ], 'PersonMatch' => [ 'base' => '<p>Information about a person whose face matches a face(s) in a Amazon Rekognition collection. Includes information about the faces in the Amazon Rekognition collection (,information about the person (<a>PersonDetail</a>) and the timestamp for when the person was detected in a video. An array of <code>PersonMatch</code> objects is returned by . </p>', 'refs' => [ 'PersonMatches$member' => NULL, ], ], 'PersonMatches' => [ 'base' => NULL, 'refs' => [ 'GetFaceSearchResponse$Persons' => '<p>An array of persons, , in the video whose face(s) match the face(s) in an Amazon Rekognition collection. It also includes time information for when persons are matched in the video. You specify the input collection in an initial call to <code>StartFaceSearch</code>. Each <code>Persons</code> element includes a time the person was matched, face match details (<code>FaceMatches</code>) for matching faces in the collection, and person information (<code>Person</code>) for the matched person. </p>', ], ], 'PersonTrackingSortBy' => [ 'base' => NULL, 'refs' => [ 'GetPersonTrackingRequest$SortBy' => '<p>Sort to use for elements in the <code>Persons</code> array. Use <code>TIMESTAMP</code> to sort array elements by the time persons are detected. Use <code>INDEX</code> to sort by the tracked persons. If you sort by <code>INDEX</code>, the array elements for each person are sorted by detection confidence. The default sort is by <code>TIMESTAMP</code>.</p>', ], ], 'Point' => [ 'base' => '<p>The X and Y coordinates of a point on an image. The X and Y values returned are ratios of the overall image size. For example, if the input image is 700x200 and the operation returns X=0.5 and Y=0.25, then the point is at the (350,50) pixel coordinate on the image.</p> <p>An array of <code>Point</code> objects, <code>Polygon</code>, is returned by . <code>Polygon</code> represents a fine-grained polygon around detected text. For more information, see . </p>', 'refs' => [ 'Polygon$member' => NULL, ], ], 'Polygon' => [ 'base' => NULL, 'refs' => [ 'Geometry$Polygon' => '<p>Within the bounding box, a fine-grained polygon around the detected text.</p>', ], ], 'Pose' => [ 'base' => '<p>Indicates the pose of the face as determined by its pitch, roll, and yaw.</p>', 'refs' => [ 'ComparedFace$Pose' => '<p>Indicates the pose of the face as determined by its pitch, roll, and yaw.</p>', 'FaceDetail$Pose' => '<p>Indicates the pose of the face as determined by its pitch, roll, and yaw.</p>', ], ], 'ProvisionedThroughputExceededException' => [ 'base' => '<p>The number of requests exceeded your throughput limit. If you want to increase this limit, contact Amazon Rekognition.</p>', 'refs' => [], ], 'RecognizeCelebritiesRequest' => [ 'base' => NULL, 'refs' => [], ], 'RecognizeCelebritiesResponse' => [ 'base' => NULL, 'refs' => [], ], 'RekognitionUniqueId' => [ 'base' => NULL, 'refs' => [ 'Celebrity$Id' => '<p>A unique identifier for the celebrity. </p>', 'CelebrityDetail$Id' => '<p>The unique identifier for the celebrity. </p>', 'GetCelebrityInfoRequest$Id' => '<p>The ID for the celebrity. You get the celebrity ID from a call to the operation, which recognizes celebrities in an image. </p>', ], ], 'ResourceAlreadyExistsException' => [ 'base' => '<p>A collection with the specified ID already exists.</p>', 'refs' => [], ], 'ResourceInUseException' => [ 'base' => '<p/>', 'refs' => [], ], 'ResourceNotFoundException' => [ 'base' => '<p>The collection specified in the request cannot be found.</p>', 'refs' => [], ], 'RoleArn' => [ 'base' => NULL, 'refs' => [ 'CreateStreamProcessorRequest$RoleArn' => '<p>ARN of the IAM role that allows access to the stream processor.</p>', 'DescribeStreamProcessorResponse$RoleArn' => '<p>ARN of the IAM role that allows access to the stream processor.</p>', 'NotificationChannel$RoleArn' => '<p>The ARN of an IAM role that gives Amazon Rekognition publishing permissions to the Amazon SNS topic. </p>', ], ], 'S3Bucket' => [ 'base' => NULL, 'refs' => [ 'S3Object$Bucket' => '<p>Name of the S3 bucket.</p>', ], ], 'S3Object' => [ 'base' => '<p>Provides the S3 bucket name and object name.</p> <p>The region for the S3 bucket containing the S3 object must match the region you use for Amazon Rekognition operations.</p> <p>For Amazon Rekognition to process an S3 object, the user must have permission to access the S3 object. For more information, see <a>manage-access-resource-policies</a>. </p>', 'refs' => [ 'Image$S3Object' => '<p>Identifies an S3 object as the image source.</p>', 'Video$S3Object' => '<p>The Amazon S3 bucket name and file name for the video.</p>', ], ], 'S3ObjectName' => [ 'base' => NULL, 'refs' => [ 'S3Object$Name' => '<p>S3 object key name.</p>', ], ], 'S3ObjectVersion' => [ 'base' => NULL, 'refs' => [ 'S3Object$Version' => '<p>If the bucket is versioning enabled, you can specify the object version. </p>', ], ], 'SNSTopicArn' => [ 'base' => NULL, 'refs' => [ 'NotificationChannel$SNSTopicArn' => '<p>The Amazon SNS topic to which Amazon Rekognition to posts the completion status.</p>', ], ], 'SearchFacesByImageRequest' => [ 'base' => NULL, 'refs' => [], ], 'SearchFacesByImageResponse' => [ 'base' => NULL, 'refs' => [], ], 'SearchFacesRequest' => [ 'base' => NULL, 'refs' => [], ], 'SearchFacesResponse' => [ 'base' => NULL, 'refs' => [], ], 'Smile' => [ 'base' => '<p>Indicates whether or not the face is smiling, and the confidence level in the determination.</p>', 'refs' => [ 'FaceDetail$Smile' => '<p>Indicates whether or not the face is smiling, and the confidence level in the determination.</p>', ], ], 'StartCelebrityRecognitionRequest' => [ 'base' => NULL, 'refs' => [], ], 'StartCelebrityRecognitionResponse' => [ 'base' => NULL, 'refs' => [], ], 'StartContentModerationRequest' => [ 'base' => NULL, 'refs' => [], ], 'StartContentModerationResponse' => [ 'base' => NULL, 'refs' => [], ], 'StartFaceDetectionRequest' => [ 'base' => NULL, 'refs' => [], ], 'StartFaceDetectionResponse' => [ 'base' => NULL, 'refs' => [], ], 'StartFaceSearchRequest' => [ 'base' => NULL, 'refs' => [], ], 'StartFaceSearchResponse' => [ 'base' => NULL, 'refs' => [], ], 'StartLabelDetectionRequest' => [ 'base' => NULL, 'refs' => [], ], 'StartLabelDetectionResponse' => [ 'base' => NULL, 'refs' => [], ], 'StartPersonTrackingRequest' => [ 'base' => NULL, 'refs' => [], ], 'StartPersonTrackingResponse' => [ 'base' => NULL, 'refs' => [], ], 'StartStreamProcessorRequest' => [ 'base' => NULL, 'refs' => [], ], 'StartStreamProcessorResponse' => [ 'base' => NULL, 'refs' => [], ], 'StatusMessage' => [ 'base' => NULL, 'refs' => [ 'GetCelebrityRecognitionResponse$StatusMessage' => '<p>If the job fails, <code>StatusMessage</code> provides a descriptive error message.</p>', 'GetContentModerationResponse$StatusMessage' => '<p>If the job fails, <code>StatusMessage</code> provides a descriptive error message.</p>', 'GetFaceDetectionResponse$StatusMessage' => '<p>If the job fails, <code>StatusMessage</code> provides a descriptive error message.</p>', 'GetFaceSearchResponse$StatusMessage' => '<p>If the job fails, <code>StatusMessage</code> provides a descriptive error message.</p>', 'GetLabelDetectionResponse$StatusMessage' => '<p>If the job fails, <code>StatusMessage</code> provides a descriptive error message.</p>', 'GetPersonTrackingResponse$StatusMessage' => '<p>If the job fails, <code>StatusMessage</code> provides a descriptive error message.</p>', ], ], 'StopStreamProcessorRequest' => [ 'base' => NULL, 'refs' => [], ], 'StopStreamProcessorResponse' => [ 'base' => NULL, 'refs' => [], ], 'StreamProcessor' => [ 'base' => '<p>An object that recognizes faces in a streaming video. An Amazon Rekognition stream processor is created by a call to . The request parameters for <code>CreateStreamProcessor</code> describe the Kinesis video stream source for the streaming video, face recognition parameters, and where to stream the analysis resullts. </p>', 'refs' => [ 'StreamProcessorList$member' => NULL, ], ], 'StreamProcessorArn' => [ 'base' => NULL, 'refs' => [ 'CreateStreamProcessorResponse$StreamProcessorArn' => '<p>ARN for the newly create stream processor.</p>', 'DescribeStreamProcessorResponse$StreamProcessorArn' => '<p>ARN of the stream processor.</p>', ], ], 'StreamProcessorInput' => [ 'base' => '<p>Information about the source streaming video. </p>', 'refs' => [ 'CreateStreamProcessorRequest$Input' => '<p>Kinesis video stream stream that provides the source streaming video. If you are using the AWS CLI, the parameter name is <code>StreamProcessorInput</code>.</p>', 'DescribeStreamProcessorResponse$Input' => '<p>Kinesis video stream that provides the source streaming video.</p>', ], ], 'StreamProcessorList' => [ 'base' => NULL, 'refs' => [ 'ListStreamProcessorsResponse$StreamProcessors' => '<p>List of stream processors that you have created.</p>', ], ], 'StreamProcessorName' => [ 'base' => NULL, 'refs' => [ 'CreateStreamProcessorRequest$Name' => '<p>An identifier you assign to the stream processor. You can use <code>Name</code> to manage the stream processor. For example, you can get the current status of the stream processor by calling . <code>Name</code> is idempotent. </p>', 'DeleteStreamProcessorRequest$Name' => '<p>The name of the stream processor you want to delete.</p>', 'DescribeStreamProcessorRequest$Name' => '<p>Name of the stream processor for which you want information.</p>', 'DescribeStreamProcessorResponse$Name' => '<p>Name of the stream processor. </p>', 'StartStreamProcessorRequest$Name' => '<p>The name of the stream processor to start processing.</p>', 'StopStreamProcessorRequest$Name' => '<p>The name of a stream processor created by .</p>', 'StreamProcessor$Name' => '<p>Name of the Amazon Rekognition stream processor. </p>', ], ], 'StreamProcessorOutput' => [ 'base' => '<p>Information about the Amazon Kinesis Data Streams stream to which a Rekognition Video stream processor streams the results of a video analysis. For more information, see .</p>', 'refs' => [ 'CreateStreamProcessorRequest$Output' => '<p>Kinesis data stream stream to which Rekognition Video puts the analysis results. If you are using the AWS CLI, the parameter name is <code>StreamProcessorOutput</code>.</p>', 'DescribeStreamProcessorResponse$Output' => '<p>Kinesis data stream to which Rekognition Video puts the analysis results.</p>', ], ], 'StreamProcessorSettings' => [ 'base' => '<p>Input parameters used to recognize faces in a streaming video analyzed by a Amazon Rekognition stream processor.</p>', 'refs' => [ 'CreateStreamProcessorRequest$Settings' => '<p>Face recognition input parameters to be used by the stream processor. Includes the collection to use for face recognition and the face attributes to detect.</p>', 'DescribeStreamProcessorResponse$Settings' => '<p>Face recognition input parameters that are being used by the stream processor. Includes the collection to use for face recognition and the face attributes to detect.</p>', ], ], 'StreamProcessorStatus' => [ 'base' => NULL, 'refs' => [ 'DescribeStreamProcessorResponse$Status' => '<p>Current status of the stream processor.</p>', 'StreamProcessor$Status' => '<p>Current status of the Amazon Rekognition stream processor.</p>', ], ], 'String' => [ 'base' => NULL, 'refs' => [ 'Celebrity$Name' => '<p>The name of the celebrity.</p>', 'CelebrityDetail$Name' => '<p>The name of the celebrity.</p>', 'CreateCollectionResponse$CollectionArn' => '<p>Amazon Resource Name (ARN) of the collection. You can use this to manage permissions on your resources. </p>', 'CreateCollectionResponse$FaceModelVersion' => '<p>Version number of the face detection model associated with the collection you are creating.</p>', 'DescribeStreamProcessorResponse$StatusMessage' => '<p>Detailed status message about the stream processor.</p>', 'FaceModelVersionList$member' => NULL, 'GetCelebrityInfoResponse$Name' => '<p>The name of the celebrity.</p>', 'IndexFacesResponse$FaceModelVersion' => '<p>Version number of the face detection model associated with the input collection (<code>CollectionId</code>).</p>', 'Label$Name' => '<p>The name (label) of the object.</p>', 'ListFacesResponse$NextToken' => '<p>If the response is truncated, Amazon Rekognition returns this token that you can use in the subsequent request to retrieve the next set of faces.</p>', 'ListFacesResponse$FaceModelVersion' => '<p>Version number of the face detection model associated with the input collection (<code>CollectionId</code>).</p>', 'ModerationLabel$Name' => '<p>The label name for the type of content detected in the image.</p>', 'ModerationLabel$ParentName' => '<p>The name for the parent label. Labels at the top-level of the hierarchy have the parent label <code>""</code>.</p>', 'SearchFacesByImageResponse$FaceModelVersion' => '<p>Version number of the face detection model associated with the input collection (<code>CollectionId</code>).</p>', 'SearchFacesResponse$FaceModelVersion' => '<p>Version number of the face detection model associated with the input collection (<code>CollectionId</code>).</p>', 'TextDetection$DetectedText' => '<p>The word or line of text recognized by Amazon Rekognition. </p>', 'VideoMetadata$Codec' => '<p>Type of compression used in the analyzed video. </p>', 'VideoMetadata$Format' => '<p>Format of the analyzed video. Possible values are MP4, MOV and AVI. </p>', ], ], 'Sunglasses' => [ 'base' => '<p>Indicates whether or not the face is wearing sunglasses, and the confidence level in the determination.</p>', 'refs' => [ 'FaceDetail$Sunglasses' => '<p>Indicates whether or not the face is wearing sunglasses, and the confidence level in the determination.</p>', ], ], 'TextDetection' => [ 'base' => '<p>Information about a word or line of text detected by .</p> <p>The <code>DetectedText</code> field contains the text that Amazon Rekognition detected in the image. </p> <p>Every word and line has an identifier (<code>Id</code>). Each word belongs to a line and has a parent identifier (<code>ParentId</code>) that identifies the line of text in which the word appears. The word <code>Id</code> is also an index for the word within a line of words. </p> <p>For more information, see <a>text-detection</a>.</p>', 'refs' => [ 'TextDetectionList$member' => NULL, ], ], 'TextDetectionList' => [ 'base' => NULL, 'refs' => [ 'DetectTextResponse$TextDetections' => '<p>An array of text that was detected in the input image.</p>', ], ], 'TextTypes' => [ 'base' => NULL, 'refs' => [ 'TextDetection$Type' => '<p>The type of text that was detected.</p>', ], ], 'ThrottlingException' => [ 'base' => '<p>Amazon Rekognition is temporarily unable to process the request. Try your call again.</p>', 'refs' => [], ], 'Timestamp' => [ 'base' => NULL, 'refs' => [ 'CelebrityRecognition$Timestamp' => '<p>The time, in milliseconds from the start of the video, that the celebrity was recognized.</p>', 'ContentModerationDetection$Timestamp' => '<p>Time, in milliseconds from the beginning of the video, that the moderation label was detected.</p>', 'FaceDetection$Timestamp' => '<p>Time, in milliseconds from the start of the video, that the face was detected.</p>', 'LabelDetection$Timestamp' => '<p>Time, in milliseconds from the start of the video, that the label was detected.</p>', 'PersonDetection$Timestamp' => '<p>The time, in milliseconds from the start of the video, that the person was tracked.</p>', 'PersonMatch$Timestamp' => '<p>The time, in milliseconds from the beginning of the video, that the person was matched in the video.</p>', ], ], 'UInteger' => [ 'base' => NULL, 'refs' => [ 'AgeRange$Low' => '<p>The lowest estimated age.</p>', 'AgeRange$High' => '<p>The highest estimated age.</p>', 'CreateCollectionResponse$StatusCode' => '<p>HTTP status code indicating the result of the operation.</p>', 'DeleteCollectionResponse$StatusCode' => '<p>HTTP status code that indicates the result of the operation.</p>', 'DetectLabelsRequest$MaxLabels' => '<p>Maximum number of labels you want the service to return in the response. The service returns the specified number of highest confidence labels. </p>', 'TextDetection$Id' => '<p>The identifier for the detected text. The identifier is only unique for a single call to <code>DetectText</code>. </p>', 'TextDetection$ParentId' => '<p>The Parent identifier for the detected text identified by the value of <code>ID</code>. If the type of detected text is <code>LINE</code>, the value of <code>ParentId</code> is <code>Null</code>. </p>', ], ], 'ULong' => [ 'base' => NULL, 'refs' => [ 'VideoMetadata$DurationMillis' => '<p>Length of the video in milliseconds.</p>', 'VideoMetadata$FrameHeight' => '<p>Vertical pixel dimension of the video.</p>', 'VideoMetadata$FrameWidth' => '<p>Horizontal pixel dimension of the video.</p>', ], ], 'Url' => [ 'base' => NULL, 'refs' => [ 'Urls$member' => NULL, ], ], 'Urls' => [ 'base' => NULL, 'refs' => [ 'Celebrity$Urls' => '<p>An array of URLs pointing to additional information about the celebrity. If there is no additional information about the celebrity, this list is empty.</p>', 'CelebrityDetail$Urls' => '<p>An array of URLs pointing to additional celebrity information. </p>', 'GetCelebrityInfoResponse$Urls' => '<p>An array of URLs pointing to additional celebrity information. </p>', ], ], 'Video' => [ 'base' => '<p>Video file stored in an Amazon S3 bucket. Amazon Rekognition video start operations such as use <code>Video</code> to specify a video for analysis. The supported file formats are .mp4, .mov and .avi.</p>', 'refs' => [ 'StartCelebrityRecognitionRequest$Video' => '<p>The video in which you want to recognize celebrities. The video must be stored in an Amazon S3 bucket.</p>', 'StartContentModerationRequest$Video' => '<p>The video in which you want to moderate content. The video must be stored in an Amazon S3 bucket.</p>', 'StartFaceDetectionRequest$Video' => '<p>The video in which you want to detect faces. The video must be stored in an Amazon S3 bucket.</p>', 'StartFaceSearchRequest$Video' => '<p>The video you want to search. The video must be stored in an Amazon S3 bucket. </p>', 'StartLabelDetectionRequest$Video' => '<p>The video in which you want to detect labels. The video must be stored in an Amazon S3 bucket.</p>', 'StartPersonTrackingRequest$Video' => '<p>The video in which you want to detect people. The video must be stored in an Amazon S3 bucket.</p>', ], ], 'VideoJobStatus' => [ 'base' => NULL, 'refs' => [ 'GetCelebrityRecognitionResponse$JobStatus' => '<p>The current status of the celebrity recognition job.</p>', 'GetContentModerationResponse$JobStatus' => '<p>The current status of the content moderation job.</p>', 'GetFaceDetectionResponse$JobStatus' => '<p>The current status of the face detection job.</p>', 'GetFaceSearchResponse$JobStatus' => '<p>The current status of the face search job.</p>', 'GetLabelDetectionResponse$JobStatus' => '<p>The current status of the label detection job.</p>', 'GetPersonTrackingResponse$JobStatus' => '<p>The current status of the person tracking job.</p>', ], ], 'VideoMetadata' => [ 'base' => '<p>Information about a video that Amazon Rekognition analyzed. <code>Videometadata</code> is returned in every page of paginated responses from a Amazon Rekognition video operation.</p>', 'refs' => [ 'GetCelebrityRecognitionResponse$VideoMetadata' => '<p>Information about a video that Rekognition Video analyzed. <code>Videometadata</code> is returned in every page of paginated responses from a Rekognition Video operation.</p>', 'GetContentModerationResponse$VideoMetadata' => '<p>Information about a video that Amazon Rekognition analyzed. <code>Videometadata</code> is returned in every page of paginated responses from <code>GetContentModeration</code>. </p>', 'GetFaceDetectionResponse$VideoMetadata' => '<p>Information about a video that Rekognition Video analyzed. <code>Videometadata</code> is returned in every page of paginated responses from a Amazon Rekognition video operation.</p>', 'GetFaceSearchResponse$VideoMetadata' => '<p>Information about a video that Amazon Rekognition analyzed. <code>Videometadata</code> is returned in every page of paginated responses from a Rekognition Video operation. </p>', 'GetLabelDetectionResponse$VideoMetadata' => '<p>Information about a video that Rekognition Video analyzed. <code>Videometadata</code> is returned in every page of paginated responses from a Amazon Rekognition video operation.</p>', 'GetPersonTrackingResponse$VideoMetadata' => '<p>Information about a video that Rekognition Video analyzed. <code>Videometadata</code> is returned in every page of paginated responses from a Rekognition Video operation.</p>', ], ], 'VideoTooLargeException' => [ 'base' => '<p>The file size or duration of the supplied media is too large. The maximum file size is 8GB. The maximum duration is 2 hours. </p>', 'refs' => [], ], ],];
