<?php
// This file was auto-generated from sdk-root/src/data/states/2016-11-23/docs-2.json
return [ 'version' => '2.0', 'service' => '<fullname>AWS Step Functions</fullname> <p>AWS Step Functions is a service that lets you coordinate the components of distributed applications and microservices using visual workflows.</p> <p>You can use Step Functions to build applications from individual components, each of which performs a discrete function, or <i>task</i>, allowing you to scale and change applications quickly. Step Functions provides a console that helps visualize the components of your application as a series of steps. Step Functions automatically triggers and tracks each step, and retries steps when there are errors, so your application executes predictably and in the right order every time. Step Functions logs the state of each step, so you can quickly diagnose and debug any issues.</p> <p>Step Functions manages operations and underlying infrastructure to ensure your application is available at any scale. You can run tasks on AWS, your own servers, or any system that has access to AWS. You can access and use Step Functions using the console, the AWS SDKs, or an HTTP API. For more information about Step Functions, see the <i> <a href="http://docs.aws.amazon.com/step-functions/latest/dg/welcome.html">AWS Step Functions Developer Guide</a> </i>.</p>', 'operations' => [ 'CreateActivity' => '<p>Creates an activity. An activity is a task which you write in any programming language and host on any machine which has access to AWS Step Functions. Activities must poll Step Functions using the <code>GetActivityTask</code> API action and respond using <code>SendTask*</code> API actions. This function lets Step Functions know the existence of your activity and returns an identifier for use in a state machine and when polling from the activity.</p>', 'CreateStateMachine' => '<p>Creates a state machine. A state machine consists of a collection of states that can do work (<code>Task</code> states), determine to which states to transition next (<code>Choice</code> states), stop an execution with an error (<code>Fail</code> states), and so on. State machines are specified using a JSON-based, structured language.</p>', 'DeleteActivity' => '<p>Deletes an activity.</p>', 'DeleteStateMachine' => '<p>Deletes a state machine. This is an asynchronous operation: It sets the state machine\'s status to <code>DELETING</code> and begins the deletion process. Each state machine execution is deleted the next time it makes a state transition.</p> <note> <p>The state machine itself is deleted after all executions are completed or deleted.</p> </note>', 'DescribeActivity' => '<p>Describes an activity.</p>', 'DescribeExecution' => '<p>Describes an execution.</p>', 'DescribeStateMachine' => '<p>Describes a state machine.</p>', 'DescribeStateMachineForExecution' => '<p>Describes the state machine associated with a specific execution.</p>', 'GetActivityTask' => '<p>Used by workers to retrieve a task (with the specified activity ARN) which has been scheduled for execution by a running state machine. This initiates a long poll, where the service holds the HTTP connection open and responds as soon as a task becomes available (i.e. an execution of a task of this type is needed.) The maximum time the service holds on to the request before responding is 60 seconds. If no task is available within 60 seconds, the poll returns a <code>taskToken</code> with a null string.</p> <important> <p>Workers should set their client side socket timeout to at least 65 seconds (5 seconds higher than the maximum time the service may hold the poll request).</p> </important>', 'GetExecutionHistory' => '<p>Returns the history of the specified execution as a list of events. By default, the results are returned in ascending order of the <code>timeStamp</code> of the events. Use the <code>reverseOrder</code> parameter to get the latest events first.</p> <p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p>', 'ListActivities' => '<p>Lists the existing activities.</p> <p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p>', 'ListExecutions' => '<p>Lists the executions of a state machine that meet the filtering criteria.</p> <p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p>', 'ListStateMachines' => '<p>Lists the existing state machines.</p> <p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p>', 'SendTaskFailure' => '<p>Used by workers to report that the task identified by the <code>taskToken</code> failed.</p>', 'SendTaskHeartbeat' => '<p>Used by workers to report to the service that the task represented by the specified <code>taskToken</code> is still making progress. This action resets the <code>Heartbeat</code> clock. The <code>Heartbeat</code> threshold is specified in the state machine\'s Amazon States Language definition. This action does not in itself create an event in the execution history. However, if the task times out, the execution history contains an <code>ActivityTimedOut</code> event.</p> <note> <p>The <code>Timeout</code> of a task, defined in the state machine\'s Amazon States Language definition, is its maximum allowed duration, regardless of the number of <a>SendTaskHeartbeat</a> requests received.</p> </note> <note> <p>This operation is only useful for long-lived tasks to report the liveliness of the task.</p> </note>', 'SendTaskSuccess' => '<p>Used by workers to report that the task identified by the <code>taskToken</code> completed successfully.</p>', 'StartExecution' => '<p>Starts a state machine execution.</p>', 'StopExecution' => '<p>Stops an execution.</p>', 'UpdateStateMachine' => '<p>Updates an existing state machine by modifying its <code>definition</code> and/or <code>roleArn</code>. Running executions will continue to use the previous <code>definition</code> and <code>roleArn</code>.</p> <note> <p>All <code>StartExecution</code> calls within a few seconds will use the updated <code>definition</code> and <code>roleArn</code>. Executions started immediately after calling <code>UpdateStateMachine</code> may use the previous state machine <code>definition</code> and <code>roleArn</code>. You must include at least one of <code>definition</code> or <code>roleArn</code> or you will receive a <code>MissingRequiredParameter</code> error.</p> </note>', ], 'shapes' => [ 'ActivityDoesNotExist' => [ 'base' => '<p>The specified activity does not exist.</p>', 'refs' => [], ], 'ActivityFailedEventDetails' => [ 'base' => '<p>Contains details about an activity which failed during an execution.</p>', 'refs' => [ 'HistoryEvent$activityFailedEventDetails' => NULL, ], ], 'ActivityLimitExceeded' => [ 'base' => '<p>The maximum number of activities has been reached. Existing activities must be deleted before a new activity can be created.</p>', 'refs' => [], ], 'ActivityList' => [ 'base' => NULL, 'refs' => [ 'ListActivitiesOutput$activities' => '<p>The list of activities.</p>', ], ], 'ActivityListItem' => [ 'base' => '<p>Contains details about an activity.</p>', 'refs' => [ 'ActivityList$member' => NULL, ], ], 'ActivityScheduleFailedEventDetails' => [ 'base' => '<p>Contains details about an activity schedule failure which occurred during an execution.</p>', 'refs' => [ 'HistoryEvent$activityScheduleFailedEventDetails' => '<p>Contains details about an activity schedule event which failed during an execution.</p>', ], ], 'ActivityScheduledEventDetails' => [ 'base' => '<p>Contains details about an activity scheduled during an execution.</p>', 'refs' => [ 'HistoryEvent$activityScheduledEventDetails' => NULL, ], ], 'ActivityStartedEventDetails' => [ 'base' => '<p>Contains details about the start of an activity during an execution.</p>', 'refs' => [ 'HistoryEvent$activityStartedEventDetails' => NULL, ], ], 'ActivitySucceededEventDetails' => [ 'base' => '<p>Contains details about an activity which successfully terminated during an execution.</p>', 'refs' => [ 'HistoryEvent$activitySucceededEventDetails' => NULL, ], ], 'ActivityTimedOutEventDetails' => [ 'base' => '<p>Contains details about an activity timeout which occurred during an execution.</p>', 'refs' => [ 'HistoryEvent$activityTimedOutEventDetails' => NULL, ], ], 'ActivityWorkerLimitExceeded' => [ 'base' => '<p>The maximum number of workers concurrently polling for activity tasks has been reached.</p>', 'refs' => [], ], 'Arn' => [ 'base' => NULL, 'refs' => [ 'ActivityListItem$activityArn' => '<p>The Amazon Resource Name (ARN) that identifies the activity.</p>', 'ActivityScheduledEventDetails$resource' => '<p>The Amazon Resource Name (ARN) of the scheduled activity.</p>', 'CreateActivityOutput$activityArn' => '<p>The Amazon Resource Name (ARN) that identifies the created activity.</p>', 'CreateStateMachineInput$roleArn' => '<p>The Amazon Resource Name (ARN) of the IAM role to use for this state machine.</p>', 'CreateStateMachineOutput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) that identifies the created state machine.</p>', 'DeleteActivityInput$activityArn' => '<p>The Amazon Resource Name (ARN) of the activity to delete.</p>', 'DeleteStateMachineInput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) of the state machine to delete.</p>', 'DescribeActivityInput$activityArn' => '<p>The Amazon Resource Name (ARN) of the activity to describe.</p>', 'DescribeActivityOutput$activityArn' => '<p>The Amazon Resource Name (ARN) that identifies the activity.</p>', 'DescribeExecutionInput$executionArn' => '<p>The Amazon Resource Name (ARN) of the execution to describe.</p>', 'DescribeExecutionOutput$executionArn' => '<p>The Amazon Resource Name (ARN) that identifies the execution.</p>', 'DescribeExecutionOutput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) of the executed stated machine.</p>', 'DescribeStateMachineForExecutionInput$executionArn' => '<p>The Amazon Resource Name (ARN) of the execution you want state machine information for.</p>', 'DescribeStateMachineForExecutionOutput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) of the state machine associated with the execution.</p>', 'DescribeStateMachineForExecutionOutput$roleArn' => '<p>The Amazon Resource Name (ARN) of the IAM role of the State Machine for the execution. </p>', 'DescribeStateMachineInput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) of the state machine to describe.</p>', 'DescribeStateMachineOutput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) that identifies the state machine.</p>', 'DescribeStateMachineOutput$roleArn' => '<p>The Amazon Resource Name (ARN) of the IAM role used when creating this state machine. (The IAM role maintains security by granting Step Functions access to AWS resources.)</p>', 'ExecutionListItem$executionArn' => '<p>The Amazon Resource Name (ARN) that identifies the execution.</p>', 'ExecutionListItem$stateMachineArn' => '<p>The Amazon Resource Name (ARN) of the executed state machine.</p>', 'ExecutionStartedEventDetails$roleArn' => '<p>The Amazon Resource Name (ARN) of the IAM role used for executing AWS Lambda tasks.</p>', 'GetActivityTaskInput$activityArn' => '<p>The Amazon Resource Name (ARN) of the activity to retrieve tasks from (assigned when you create the task using <a>CreateActivity</a>.)</p>', 'GetExecutionHistoryInput$executionArn' => '<p>The Amazon Resource Name (ARN) of the execution.</p>', 'LambdaFunctionScheduledEventDetails$resource' => '<p>The Amazon Resource Name (ARN) of the scheduled lambda function.</p>', 'ListExecutionsInput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) of the state machine whose executions is listed.</p>', 'StartExecutionInput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) of the state machine to execute.</p>', 'StartExecutionOutput$executionArn' => '<p>The Amazon Resource Name (ARN) that identifies the execution.</p>', 'StateMachineListItem$stateMachineArn' => '<p>The Amazon Resource Name (ARN) that identifies the state machine.</p>', 'StopExecutionInput$executionArn' => '<p>The Amazon Resource Name (ARN) of the execution to stop.</p>', 'UpdateStateMachineInput$stateMachineArn' => '<p>The Amazon Resource Name (ARN) of the state machine.</p>', 'UpdateStateMachineInput$roleArn' => '<p>The Amazon Resource Name (ARN) of the IAM role of the state machine.</p>', ], ], 'Cause' => [ 'base' => NULL, 'refs' => [ 'ActivityFailedEventDetails$cause' => '<p>A more detailed explanation of the cause of the failure.</p>', 'ActivityScheduleFailedEventDetails$cause' => '<p>A more detailed explanation of the cause of the failure.</p>', 'ActivityTimedOutEventDetails$cause' => '<p>A more detailed explanation of the cause of the timeout.</p>', 'ExecutionAbortedEventDetails$cause' => '<p>A more detailed explanation of the cause of the failure.</p>', 'ExecutionFailedEventDetails$cause' => '<p>A more detailed explanation of the cause of the failure.</p>', 'ExecutionTimedOutEventDetails$cause' => '<p>A more detailed explanation of the cause of the timeout.</p>', 'LambdaFunctionFailedEventDetails$cause' => '<p>A more detailed explanation of the cause of the failure.</p>', 'LambdaFunctionScheduleFailedEventDetails$cause' => '<p>A more detailed explanation of the cause of the failure.</p>', 'LambdaFunctionStartFailedEventDetails$cause' => '<p>A more detailed explanation of the cause of the failure.</p>', 'LambdaFunctionTimedOutEventDetails$cause' => '<p>A more detailed explanation of the cause of the timeout.</p>', 'SendTaskFailureInput$cause' => '<p>A more detailed explanation of the cause of the failure.</p>', 'StopExecutionInput$cause' => '<p>A more detailed explanation of the cause of the termination.</p>', ], ], 'CreateActivityInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateActivityOutput' => [ 'base' => NULL, 'refs' => [], ], 'CreateStateMachineInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateStateMachineOutput' => [ 'base' => NULL, 'refs' => [], ], 'Data' => [ 'base' => NULL, 'refs' => [ 'ActivityScheduledEventDetails$input' => '<p>The JSON data input to the activity task.</p>', 'ActivitySucceededEventDetails$output' => '<p>The JSON data output by the activity task.</p>', 'DescribeExecutionOutput$input' => '<p>The string that contains the JSON input data of the execution.</p>', 'DescribeExecutionOutput$output' => '<p>The JSON output data of the execution.</p> <note> <p>This field is set only if the execution succeeds. If the execution fails, this field is null.</p> </note>', 'ExecutionStartedEventDetails$input' => '<p>The JSON data input to the execution.</p>', 'ExecutionSucceededEventDetails$output' => '<p>The JSON data output by the execution.</p>', 'GetActivityTaskOutput$input' => '<p>The string that contains the JSON input data for the task.</p>', 'LambdaFunctionScheduledEventDetails$input' => '<p>The JSON data input to the lambda function.</p>', 'LambdaFunctionSucceededEventDetails$output' => '<p>The JSON data output by the lambda function.</p>', 'SendTaskSuccessInput$output' => '<p>The JSON output of the task.</p>', 'StartExecutionInput$input' => '<p>The string that contains the JSON input data for the execution, for example:</p> <p> <code>"input": "{\\"first_name\\" : \\"test\\"}"</code> </p> <note> <p>If you don\'t include any JSON input data, you still must include the two braces, for example: <code>"input": "{}"</code> </p> </note>', 'StateEnteredEventDetails$input' => '<p>The string that contains the JSON input data for the state.</p>', 'StateExitedEventDetails$output' => '<p>The JSON output data of the state.</p>', ], ], 'Definition' => [ 'base' => NULL, 'refs' => [ 'CreateStateMachineInput$definition' => '<p>The Amazon States Language definition of the state machine.</p>', 'DescribeStateMachineForExecutionOutput$definition' => '<p>The Amazon States Language definition of the state machine.</p>', 'DescribeStateMachineOutput$definition' => '<p>The Amazon States Language definition of the state machine.</p>', 'UpdateStateMachineInput$definition' => '<p>The Amazon States Language definition of the state machine.</p>', ], ], 'DeleteActivityInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteActivityOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteStateMachineInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteStateMachineOutput' => [ 'base' => NULL, 'refs' => [], ], 'DescribeActivityInput' => [ 'base' => NULL, 'refs' => [], ], 'DescribeActivityOutput' => [ 'base' => NULL, 'refs' => [], ], 'DescribeExecutionInput' => [ 'base' => NULL, 'refs' => [], ], 'DescribeExecutionOutput' => [ 'base' => NULL, 'refs' => [], ], 'DescribeStateMachineForExecutionInput' => [ 'base' => NULL, 'refs' => [], ], 'DescribeStateMachineForExecutionOutput' => [ 'base' => NULL, 'refs' => [], ], 'DescribeStateMachineInput' => [ 'base' => NULL, 'refs' => [], ], 'DescribeStateMachineOutput' => [ 'base' => NULL, 'refs' => [], ], 'Error' => [ 'base' => NULL, 'refs' => [ 'ActivityFailedEventDetails$error' => '<p>The error code of the failure.</p>', 'ActivityScheduleFailedEventDetails$error' => '<p>The error code of the failure.</p>', 'ActivityTimedOutEventDetails$error' => '<p>The error code of the failure.</p>', 'ExecutionAbortedEventDetails$error' => '<p>The error code of the failure.</p>', 'ExecutionFailedEventDetails$error' => '<p>The error code of the failure.</p>', 'ExecutionTimedOutEventDetails$error' => '<p>The error code of the failure.</p>', 'LambdaFunctionFailedEventDetails$error' => '<p>The error code of the failure.</p>', 'LambdaFunctionScheduleFailedEventDetails$error' => '<p>The error code of the failure.</p>', 'LambdaFunctionStartFailedEventDetails$error' => '<p>The error code of the failure.</p>', 'LambdaFunctionTimedOutEventDetails$error' => '<p>The error code of the failure.</p>', 'SendTaskFailureInput$error' => '<p>An arbitrary error code that identifies the cause of the failure.</p>', 'StopExecutionInput$error' => '<p>An arbitrary error code that identifies the cause of the termination.</p>', ], ], 'ErrorMessage' => [ 'base' => NULL, 'refs' => [ 'ActivityDoesNotExist$message' => NULL, 'ActivityLimitExceeded$message' => NULL, 'ActivityWorkerLimitExceeded$message' => NULL, 'ExecutionAlreadyExists$message' => NULL, 'ExecutionDoesNotExist$message' => NULL, 'ExecutionLimitExceeded$message' => NULL, 'InvalidArn$message' => NULL, 'InvalidDefinition$message' => NULL, 'InvalidExecutionInput$message' => NULL, 'InvalidName$message' => NULL, 'InvalidOutput$message' => NULL, 'InvalidToken$message' => NULL, 'MissingRequiredParameter$message' => NULL, 'StateMachineAlreadyExists$message' => NULL, 'StateMachineDeleting$message' => NULL, 'StateMachineDoesNotExist$message' => NULL, 'StateMachineLimitExceeded$message' => NULL, 'TaskDoesNotExist$message' => NULL, 'TaskTimedOut$message' => NULL, ], ], 'EventId' => [ 'base' => NULL, 'refs' => [ 'HistoryEvent$id' => '<p>The id of the event. Events are numbered sequentially, starting at one.</p>', 'HistoryEvent$previousEventId' => '<p>The id of the previous event.</p>', ], ], 'ExecutionAbortedEventDetails' => [ 'base' => '<p>Contains details about an abort of an execution.</p>', 'refs' => [ 'HistoryEvent$executionAbortedEventDetails' => NULL, ], ], 'ExecutionAlreadyExists' => [ 'base' => '<p>The execution has the same <code>name</code> as another execution (but a different <code>input</code>).</p> <note> <p>Executions with the same <code>name</code> and <code>input</code> are considered idempotent.</p> </note>', 'refs' => [], ], 'ExecutionDoesNotExist' => [ 'base' => '<p>The specified execution does not exist.</p>', 'refs' => [], ], 'ExecutionFailedEventDetails' => [ 'base' => '<p>Contains details about an execution failure event.</p>', 'refs' => [ 'HistoryEvent$executionFailedEventDetails' => NULL, ], ], 'ExecutionLimitExceeded' => [ 'base' => '<p>The maximum number of running executions has been reached. Running executions must end or be stopped before a new execution can be started.</p>', 'refs' => [], ], 'ExecutionList' => [ 'base' => NULL, 'refs' => [ 'ListExecutionsOutput$executions' => '<p>The list of matching executions.</p>', ], ], 'ExecutionListItem' => [ 'base' => '<p>Contains details about an execution.</p>', 'refs' => [ 'ExecutionList$member' => NULL, ], ], 'ExecutionStartedEventDetails' => [ 'base' => '<p>Contains details about the start of the execution.</p>', 'refs' => [ 'HistoryEvent$executionStartedEventDetails' => NULL, ], ], 'ExecutionStatus' => [ 'base' => NULL, 'refs' => [ 'DescribeExecutionOutput$status' => '<p>The current status of the execution.</p>', 'ExecutionListItem$status' => '<p>The current status of the execution.</p>', 'ListExecutionsInput$statusFilter' => '<p>If specified, only list the executions whose current execution status matches the given filter.</p>', ], ], 'ExecutionSucceededEventDetails' => [ 'base' => '<p>Contains details about the successful termination of the execution.</p>', 'refs' => [ 'HistoryEvent$executionSucceededEventDetails' => NULL, ], ], 'ExecutionTimedOutEventDetails' => [ 'base' => '<p>Contains details about the execution timeout which occurred during the execution.</p>', 'refs' => [ 'HistoryEvent$executionTimedOutEventDetails' => NULL, ], ], 'GetActivityTaskInput' => [ 'base' => NULL, 'refs' => [], ], 'GetActivityTaskOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetExecutionHistoryInput' => [ 'base' => NULL, 'refs' => [], ], 'GetExecutionHistoryOutput' => [ 'base' => NULL, 'refs' => [], ], 'HistoryEvent' => [ 'base' => '<p>Contains details about the events of an execution.</p>', 'refs' => [ 'HistoryEventList$member' => NULL, ], ], 'HistoryEventList' => [ 'base' => '<p>Contains details about the events which occurred during an execution.</p>', 'refs' => [ 'GetExecutionHistoryOutput$events' => '<p>The list of events that occurred in the execution.</p>', ], ], 'HistoryEventType' => [ 'base' => NULL, 'refs' => [ 'HistoryEvent$type' => '<p>The type of the event.</p>', ], ], 'Identity' => [ 'base' => NULL, 'refs' => [ 'ActivityStartedEventDetails$workerName' => '<p>The name of the worker that the task is assigned to. These names are provided by the workers when calling <a>GetActivityTask</a>.</p>', ], ], 'InvalidArn' => [ 'base' => '<p>The provided Amazon Resource Name (ARN) is invalid.</p>', 'refs' => [], ], 'InvalidDefinition' => [ 'base' => '<p>The provided Amazon States Language definition is invalid.</p>', 'refs' => [], ], 'InvalidExecutionInput' => [ 'base' => '<p>The provided JSON input data is invalid.</p>', 'refs' => [], ], 'InvalidName' => [ 'base' => '<p>The provided name is invalid.</p>', 'refs' => [], ], 'InvalidOutput' => [ 'base' => '<p>The provided JSON output data is invalid.</p>', 'refs' => [], ], 'InvalidToken' => [ 'base' => '<p>The provided token is invalid.</p>', 'refs' => [], ], 'LambdaFunctionFailedEventDetails' => [ 'base' => '<p>Contains details about a lambda function which failed during an execution.</p>', 'refs' => [ 'HistoryEvent$lambdaFunctionFailedEventDetails' => NULL, ], ], 'LambdaFunctionScheduleFailedEventDetails' => [ 'base' => '<p>Contains details about a failed lambda function schedule event which occurred during an execution.</p>', 'refs' => [ 'HistoryEvent$lambdaFunctionScheduleFailedEventDetails' => NULL, ], ], 'LambdaFunctionScheduledEventDetails' => [ 'base' => '<p>Contains details about a lambda function scheduled during an execution.</p>', 'refs' => [ 'HistoryEvent$lambdaFunctionScheduledEventDetails' => NULL, ], ], 'LambdaFunctionStartFailedEventDetails' => [ 'base' => '<p>Contains details about a lambda function which failed to start during an execution.</p>', 'refs' => [ 'HistoryEvent$lambdaFunctionStartFailedEventDetails' => '<p>Contains details about a lambda function which failed to start during an execution.</p>', ], ], 'LambdaFunctionSucceededEventDetails' => [ 'base' => '<p>Contains details about a lambda function which successfully terminated during an execution.</p>', 'refs' => [ 'HistoryEvent$lambdaFunctionSucceededEventDetails' => '<p>Contains details about a lambda function which terminated successfully during an execution.</p>', ], ], 'LambdaFunctionTimedOutEventDetails' => [ 'base' => '<p>Contains details about a lambda function timeout which occurred during an execution.</p>', 'refs' => [ 'HistoryEvent$lambdaFunctionTimedOutEventDetails' => NULL, ], ], 'ListActivitiesInput' => [ 'base' => NULL, 'refs' => [], ], 'ListActivitiesOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListExecutionsInput' => [ 'base' => NULL, 'refs' => [], ], 'ListExecutionsOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListStateMachinesInput' => [ 'base' => NULL, 'refs' => [], ], 'ListStateMachinesOutput' => [ 'base' => NULL, 'refs' => [], ], 'MissingRequiredParameter' => [ 'base' => '<p>Request is missing a required parameter. This error occurs if both <code>definition</code> and <code>roleArn</code> are not specified.</p>', 'refs' => [], ], 'Name' => [ 'base' => NULL, 'refs' => [ 'ActivityListItem$name' => '<p>The name of the activity.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'CreateActivityInput$name' => '<p>The name of the activity to create. This name must be unique for your AWS account and region for 90 days. For more information, see <a href="http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions"> Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'CreateStateMachineInput$name' => '<p>The name of the state machine. This name must be unique for your AWS account and region for 90 days. For more information, see <a href="http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions"> Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'DescribeActivityOutput$name' => '<p>The name of the activity.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'DescribeExecutionOutput$name' => '<p>The name of the execution.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'DescribeStateMachineForExecutionOutput$name' => '<p>The name of the state machine associated with the execution.</p>', 'DescribeStateMachineOutput$name' => '<p>The name of the state machine.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'ExecutionListItem$name' => '<p>The name of the execution.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'GetActivityTaskInput$workerName' => '<p>You can provide an arbitrary name in order to identify the worker that the task is assigned to. This name is used when it is logged in the execution history.</p>', 'StartExecutionInput$name' => '<p>The name of the execution. This name must be unique for your AWS account and region for 90 days. For more information, see <a href="http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions"> Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.</p> <important> <p>An execution can\'t use the name of another execution for 90 days.</p> <p>When you make multiple <code>StartExecution</code> calls with the same name, the new execution doesn\'t run and the following rules apply:</p> <ul> <li> <p>When the original execution is open and the execution input from the new call is <i>different</i>, the <code>ExecutionAlreadyExists</code> message is returned.</p> </li> <li> <p>When the original execution is open and the execution input from the new call is <i>identical</i>, the <code>Success</code> message is returned.</p> </li> <li> <p>When the original execution is closed, the <code>ExecutionAlreadyExists</code> message is returned regardless of input.</p> </li> </ul> </important> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'StateEnteredEventDetails$name' => '<p>The name of the state.</p>', 'StateExitedEventDetails$name' => '<p>The name of the state.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', 'StateMachineListItem$name' => '<p>The name of the state machine.</p> <p>A name must <i>not</i> contain:</p> <ul> <li> <p>whitespace</p> </li> <li> <p>brackets <code>&lt; &gt; { } [ ]</code> </p> </li> <li> <p>wildcard characters <code>? *</code> </p> </li> <li> <p>special characters <code>" # % \\ ^ | ~ ` $ &amp; , ; : /</code> </p> </li> <li> <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p> </li> </ul>', ], ], 'PageSize' => [ 'base' => NULL, 'refs' => [ 'GetExecutionHistoryInput$maxResults' => '<p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results. The default is 100 and the maximum allowed page size is 100. A value of 0 uses the default.</p> <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>', 'ListActivitiesInput$maxResults' => '<p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results. The default is 100 and the maximum allowed page size is 100. A value of 0 uses the default.</p> <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>', 'ListExecutionsInput$maxResults' => '<p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results. The default is 100 and the maximum allowed page size is 100. A value of 0 uses the default.</p> <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>', 'ListStateMachinesInput$maxResults' => '<p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results. The default is 100 and the maximum allowed page size is 100. A value of 0 uses the default.</p> <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>', ], ], 'PageToken' => [ 'base' => NULL, 'refs' => [ 'GetExecutionHistoryInput$nextToken' => '<p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p> <p>The configured <code>maxResults</code> determines how many results can be returned in a single call.</p>', 'GetExecutionHistoryOutput$nextToken' => '<p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p> <p>The configured <code>maxResults</code> determines how many results can be returned in a single call.</p>', 'ListActivitiesInput$nextToken' => '<p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p> <p>The configured <code>maxResults</code> determines how many results can be returned in a single call.</p>', 'ListActivitiesOutput$nextToken' => '<p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p> <p>The configured <code>maxResults</code> determines how many results can be returned in a single call.</p>', 'ListExecutionsInput$nextToken' => '<p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p> <p>The configured <code>maxResults</code> determines how many results can be returned in a single call.</p>', 'ListExecutionsOutput$nextToken' => '<p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p> <p>The configured <code>maxResults</code> determines how many results can be returned in a single call.</p>', 'ListStateMachinesInput$nextToken' => '<p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p> <p>The configured <code>maxResults</code> determines how many results can be returned in a single call.</p>', 'ListStateMachinesOutput$nextToken' => '<p>If a <code>nextToken</code> is returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in <code>nextToken</code>. Keep all other arguments unchanged.</p> <p>The configured <code>maxResults</code> determines how many results can be returned in a single call.</p>', ], ], 'ReverseOrder' => [ 'base' => NULL, 'refs' => [ 'GetExecutionHistoryInput$reverseOrder' => '<p>Lists events in descending order of their <code>timeStamp</code>.</p>', ], ], 'SendTaskFailureInput' => [ 'base' => NULL, 'refs' => [], ], 'SendTaskFailureOutput' => [ 'base' => NULL, 'refs' => [], ], 'SendTaskHeartbeatInput' => [ 'base' => NULL, 'refs' => [], ], 'SendTaskHeartbeatOutput' => [ 'base' => NULL, 'refs' => [], ], 'SendTaskSuccessInput' => [ 'base' => NULL, 'refs' => [], ], 'SendTaskSuccessOutput' => [ 'base' => NULL, 'refs' => [], ], 'StartExecutionInput' => [ 'base' => NULL, 'refs' => [], ], 'StartExecutionOutput' => [ 'base' => NULL, 'refs' => [], ], 'StateEnteredEventDetails' => [ 'base' => '<p>Contains details about a state entered during an execution.</p>', 'refs' => [ 'HistoryEvent$stateEnteredEventDetails' => NULL, ], ], 'StateExitedEventDetails' => [ 'base' => '<p>Contains details about an exit from a state during an execution.</p>', 'refs' => [ 'HistoryEvent$stateExitedEventDetails' => NULL, ], ], 'StateMachineAlreadyExists' => [ 'base' => '<p>A state machine with the same name but a different definition or role ARN already exists.</p>', 'refs' => [], ], 'StateMachineDeleting' => [ 'base' => '<p>The specified state machine is being deleted.</p>', 'refs' => [], ], 'StateMachineDoesNotExist' => [ 'base' => '<p>The specified state machine does not exist.</p>', 'refs' => [], ], 'StateMachineLimitExceeded' => [ 'base' => '<p>The maximum number of state machines has been reached. Existing state machines must be deleted before a new state machine can be created.</p>', 'refs' => [], ], 'StateMachineList' => [ 'base' => NULL, 'refs' => [ 'ListStateMachinesOutput$stateMachines' => NULL, ], ], 'StateMachineListItem' => [ 'base' => '<p>Contains details about the state machine.</p>', 'refs' => [ 'StateMachineList$member' => NULL, ], ], 'StateMachineStatus' => [ 'base' => NULL, 'refs' => [ 'DescribeStateMachineOutput$status' => '<p>The current status of the state machine.</p>', ], ], 'StopExecutionInput' => [ 'base' => NULL, 'refs' => [], ], 'StopExecutionOutput' => [ 'base' => NULL, 'refs' => [], ], 'TaskDoesNotExist' => [ 'base' => NULL, 'refs' => [], ], 'TaskTimedOut' => [ 'base' => NULL, 'refs' => [], ], 'TaskToken' => [ 'base' => NULL, 'refs' => [ 'GetActivityTaskOutput$taskToken' => '<p>A token that identifies the scheduled task. This token must be copied and included in subsequent calls to <a>SendTaskHeartbeat</a>, <a>SendTaskSuccess</a> or <a>SendTaskFailure</a> in order to report the progress or completion of the task.</p>', 'SendTaskFailureInput$taskToken' => '<p>The token that represents this task. Task tokens are generated by the service when the tasks are assigned to a worker (see GetActivityTask::taskToken).</p>', 'SendTaskHeartbeatInput$taskToken' => '<p>The token that represents this task. Task tokens are generated by the service when the tasks are assigned to a worker (see <a>GetActivityTaskOutput$taskToken</a>).</p>', 'SendTaskSuccessInput$taskToken' => '<p>The token that represents this task. Task tokens are generated by the service when the tasks are assigned to a worker (see <a>GetActivityTaskOutput$taskToken</a>).</p>', ], ], 'TimeoutInSeconds' => [ 'base' => NULL, 'refs' => [ 'ActivityScheduledEventDetails$timeoutInSeconds' => '<p>The maximum allowed duration of the activity task.</p>', 'ActivityScheduledEventDetails$heartbeatInSeconds' => '<p>The maximum allowed duration between two heartbeats for the activity task.</p>', 'LambdaFunctionScheduledEventDetails$timeoutInSeconds' => '<p>The maximum allowed duration of the lambda function.</p>', ], ], 'Timestamp' => [ 'base' => NULL, 'refs' => [ 'ActivityListItem$creationDate' => '<p>The date the activity is created.</p>', 'CreateActivityOutput$creationDate' => '<p>The date the activity is created.</p>', 'CreateStateMachineOutput$creationDate' => '<p>The date the state machine is created.</p>', 'DescribeActivityOutput$creationDate' => '<p>The date the activity is created.</p>', 'DescribeExecutionOutput$startDate' => '<p>The date the execution is started.</p>', 'DescribeExecutionOutput$stopDate' => '<p>If the execution has already ended, the date the execution stopped.</p>', 'DescribeStateMachineForExecutionOutput$updateDate' => '<p>The date and time the state machine associated with an execution was updated. For a newly created state machine, this is the creation date.</p>', 'DescribeStateMachineOutput$creationDate' => '<p>The date the state machine is created.</p>', 'ExecutionListItem$startDate' => '<p>The date the execution started.</p>', 'ExecutionListItem$stopDate' => '<p>If the execution already ended, the date the execution stopped.</p>', 'HistoryEvent$timestamp' => '<p>The date the event occurred.</p>', 'StartExecutionOutput$startDate' => '<p>The date the execution is started.</p>', 'StateMachineListItem$creationDate' => '<p>The date the state machine is created.</p>', 'StopExecutionOutput$stopDate' => '<p>The date the execution is stopped.</p>', 'UpdateStateMachineOutput$updateDate' => '<p>The date and time the state machine was updated.</p>', ], ], 'UpdateStateMachineInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateStateMachineOutput' => [ 'base' => NULL, 'refs' => [], ], ],];
